@@ -1,19 +1,22 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="fi">
-<defaultcodec></defaultcodec>
+<!DOCTYPE TS>
+<TS version="2.0" language="fi">
 <context>
     <name>QmmpFileDialog</name>
     <message>
         <location filename="../qmmpfiledialog.ui" line="13"/>
         <source>Add Files</source>
-        <translation>Datei(en) hinzufügen</translation>
+        <translation>Dateien hinzufügen</translation>
     </message>
     <message>
         <location filename="../qmmpfiledialog.ui" line="37"/>
         <source>Up</source>
-        <translation>Übergeordnetes Verzeichnis</translation>
+        <translation>Nach oben</translation>
     </message>
     <message>
+        <location filename="../qmmpfiledialog.ui" line="40"/>
+        <location filename="../qmmpfiledialog.ui" line="53"/>
+        <location filename="../qmmpfiledialog.ui" line="72"/>
         <location filename="../qmmpfiledialog.ui" line="97"/>
         <source>...</source>
         <translation>...</translation>
@@ -26,7 +29,7 @@
     <message>
         <location filename="../qmmpfiledialog.ui" line="69"/>
         <source>Detailed view</source>
-        <translation>Details</translation>
+        <translation>Detailansicht</translation>
     </message>
     <message>
         <location filename="../qmmpfiledialog.ui" line="94"/>
@@ -34,22 +37,22 @@
         <translation>Dialog nach Hinzufügen schließen</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.ui" line="168"/>
+        <location filename="../qmmpfiledialog.ui" line="177"/>
         <source>File name:</source>
         <translation>Dateiname:</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.ui" line="184"/>
+        <location filename="../qmmpfiledialog.ui" line="193"/>
         <source>Add</source>
         <translation>Hinzufügen</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.ui" line="191"/>
+        <location filename="../qmmpfiledialog.ui" line="200"/>
         <source>Files of type:</source>
-        <translation>Dateien des Typs:</translation>
+        <translation>Filter:</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.ui" line="217"/>
+        <location filename="../qmmpfiledialog.ui" line="226"/>
         <source>Close</source>
         <translation>Schließen</translation>
     </message>
@@ -57,17 +60,18 @@
 <context>
     <name>QmmpFileDialogFactory</name>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="107"/>
+        <location filename="../qmmpfiledialog.cpp" line="121"/>
+        <location filename="../qmmpfiledialog.cpp" line="130"/>
         <source>Qmmp File Dialog</source>
-        <translation>Qmmp Datei Dialog</translation>
+        <translation>Qmmp Datei-Dialog</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="106"/>
+        <location filename="../qmmpfiledialog.cpp" line="129"/>
         <source>About Qmmp File Dialog</source>
         <translation>Über Qmmp Datei-Dialog</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="110"/>
+        <location filename="../qmmpfiledialog.cpp" line="131"/>
         <source>Writen by:
 Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
 Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
@@ -76,37 +80,37 @@ Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
 Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="111"/>
+        <location filename="../qmmpfiledialog.cpp" line="134"/>
         <source>Some code is copied from the Qt library</source>
-        <translation>Einige Kodezeilen wurden von der Qt-Bibliothek übernommen</translation>
+        <translation>Einige Codezeilen wurden von der Qt-Bibliothek übernommen</translation>
     </message>
 </context>
 <context>
     <name>QmmpFileDialogImpl</name>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="215"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="259"/>
         <source>Add</source>
         <translation>Hinzufügen</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="228"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="272"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="240"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="288"/>
         <source>Directories</source>
-        <translation>Verzeichnis</translation>
+        <translation>Verzeichnisse</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="384"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="457"/>
         <source>already exists.</source>
         <translation>existiert bereits.</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="385"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="458"/>
         <source>Do you want to replace it?</source>
-        <translation>Möchten Sie das Verzeichnis ersetzen?</translation>
+        <translation>Möchten Sie es ersetzen?</translation>
     </message>
 </context>
 </TS>
