@@ -28,13 +28,14 @@ const GeneralProperties NotifierFactory::properties() const
 {
     GeneralProperties properties;
     properties.name = tr("Notifier Plugin");
+    properties.shortName = "notifier";
     properties.hasAbout = TRUE;
     properties.hasSettings = TRUE;
     properties.visibilityControl = FALSE;
     return properties;
 }
 
-General *NotifierFactory::create(Control*, QObject *parent)
+General *NotifierFactory::create(QObject *parent)
 {
     return new Notifier(parent);
 }
@@ -54,7 +55,7 @@ void NotifierFactory::showAbout(QWidget *parent)
 QTranslator *NotifierFactory::createTranslator(QObject *parent)
 {
     QTranslator *translator = new QTranslator(parent);
-    QString locale = QLocale::system().name();
+    QString locale = Qmmp::systemLanguageID();
     translator->load(QString(":/notifier_plugin_") + locale);
     return translator;
 }
