@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="zh_CN">
-<defaultcodec></defaultcodec>
+<!DOCTYPE TS>
+<TS version="2.0" language="zh_CN">
 <context>
     <name>NotifierFactory</name>
     <message>
@@ -9,28 +9,31 @@
         <translation>通知插件</translation>
     </message>
     <message>
-        <location filename="../notifierfactory.cpp" line="49"/>
+        <location filename="../notifierfactory.cpp" line="50"/>
         <source>About Notifier Plugin</source>
         <translation>关于通知插件</translation>
     </message>
     <message>
-        <location filename="../notifierfactory.cpp" line="50"/>
+        <location filename="../notifierfactory.cpp" line="51"/>
         <source>Qmmp Notifier Plugin</source>
         <translation>Qmmp 通知插件</translation>
     </message>
     <message>
-        <location filename="../notifierfactory.cpp" line="51"/>
+        <location filename="../notifierfactory.cpp" line="52"/>
         <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>PopupWidget</name>
     <message>
-        <location filename="../settingsdialog.ui" line="13"/>
-        <source>Status Icon Plugin Settings</source>
-        <translation type="obsolete">状态图标插件设置</translation>
+        <location filename="../popupwidget.cpp" line="115"/>
+        <source>Volume:</source>
+        <translation>音量：</translation>
     </message>
+</context>
+<context>
+    <name>SettingsDialog</name>
     <message>
         <location filename="../settingsdialog.ui" line="19"/>
         <source>Psi Notification</source>
@@ -47,34 +50,39 @@
         <translation>桌面通知</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="41"/>
-        <source>Enable desktop notification</source>
-        <translation>启用桌面通知</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="48"/>
-        <source>Message delay, ms:</source>
-        <translation>消息延时(ms)：</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="74"/>
+        <location filename="../settingsdialog.ui" line="248"/>
         <source>Position</source>
         <translation>位置</translation>
     </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="248"/>
-        <source>OK</source>
-        <translation>确定</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="255"/>
-        <source>Cancel</source>
-        <translation>取消</translation>
-    </message>
     <message>
         <location filename="../settingsdialog.ui" line="13"/>
         <source>Notifier Plugin Settings</source>
         <translation>通知插件设置</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="41"/>
+        <source>Song change notification</source>
+        <translation>歌曲更改通知</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="48"/>
+        <source>Volume change notification</source>
+        <translation>音量更改通知</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="55"/>
+        <source>Delay, ms:</source>
+        <translation>延迟(ms)：</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="81"/>
+        <source>Transparency</source>
+        <translation>透明度</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="104"/>
+        <source>0</source>
+        <translation>0</translation>
+    </message>
 </context>
 </TS>
