@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Ilya Kotov                                      *
+ *   Copyright (C) 2008-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,8 +19,8 @@
  ***************************************************************************/
 
 #include <QtGui>
-
-#include "scrobbler.h"
+#include <qmmp/qmmp.h>
+#include "scrobblerhandler.h"
 #include "settingsdialog.h"
 #include "scrobblerfactory.h"
 
@@ -28,15 +28,16 @@ const GeneralProperties ScrobblerFactory::properties() const
 {
     GeneralProperties properties;
     properties.name = tr("Scrobbler Plugin");
+    properties.shortName = "scrobbler";
     properties.hasAbout = TRUE;
     properties.hasSettings = TRUE;
     properties.visibilityControl = FALSE;
     return properties;
 }
 
-General *ScrobblerFactory::create(Control*, QObject *parent)
+General *ScrobblerFactory::create(QObject *parent)
 {
-    return new Scrobbler(parent);
+    return new ScrobblerHandler(parent);
 }
 
 QDialog *ScrobblerFactory::createConfigDialog(QWidget *parent)
@@ -54,7 +55,7 @@ void ScrobblerFactory::showAbout(QWidget *parent)
 QTranslator *ScrobblerFactory::createTranslator(QObject *parent)
 {
     QTranslator *translator = new QTranslator(parent);
-    QString locale = QLocale::system().name();
+    QString locale = Qmmp::systemLanguageID();
     translator->load(QString(":/scrobbler_plugin_") + locale);
     return translator;
 }
