@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="cs">
+<!DOCTYPE TS>
+<TS version="2.0" language="cs">
 <context>
     <name>ScrobblerFactory</name>
     <message>
@@ -8,17 +9,17 @@
         <translation>Modul Scrobbler</translation>
     </message>
     <message>
-        <location filename="../scrobblerfactory.cpp" line="49"/>
+        <location filename="../scrobblerfactory.cpp" line="50"/>
         <source>About Scrobbler Plugin</source>
         <translation>O modulu Scrobbler</translation>
     </message>
     <message>
-        <location filename="../scrobblerfactory.cpp" line="50"/>
+        <location filename="../scrobblerfactory.cpp" line="51"/>
         <source>Qmmp AudioScrobbler Plugin</source>
         <translation>Modul Qmmp Scrobbler</translation>
     </message>
     <message>
-        <location filename="../scrobblerfactory.cpp" line="51"/>
+        <location filename="../scrobblerfactory.cpp" line="52"/>
         <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
@@ -26,29 +27,31 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="58"/>
-        <source>OK</source>
-        <translation>OK</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="65"/>
-        <source>Cancel</source>
-        <translation>Zrušit</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="13"/>
+        <location filename="../settingsdialog.ui" line="14"/>
         <source>Scrobbler Plugin Settings</source>
         <translation>Nastavení modulu Scrobbler</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="19"/>
+        <location filename="../settingsdialog.ui" line="32"/>
+        <source>Last.fm</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="41"/>
+        <location filename="../settingsdialog.ui" line="77"/>
         <source>User name:</source>
         <translation>Uživatelské jméno:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="29"/>
+        <location filename="../settingsdialog.ui" line="51"/>
+        <location filename="../settingsdialog.ui" line="87"/>
         <source>Password:</source>
         <translation>Heslo:</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="68"/>
+        <source>Libre.fm</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
