@@ -1,73 +1,68 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="de">
-<defaultcodec></defaultcodec>
+<!DOCTYPE TS>
+<TS version="2.0" language="de">
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="13"/>
+        <location filename="../settingsdialog.ui" line="14"/>
         <source>Status Icon Plugin Settings</source>
-        <translation>Status Icon Plugin Einstellungen</translation>
+        <translation>Einstellungen Statussymbol-Modul</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="19"/>
+        <location filename="../settingsdialog.ui" line="20"/>
         <source>Show message</source>
         <translation>Mitteilung anzeigen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="26"/>
+        <location filename="../settingsdialog.ui" line="27"/>
         <source>Show tooltip</source>
-        <translation>QuickInfo anzeigen</translation>
+        <translation>Kurzinfo anzeigen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="33"/>
+        <location filename="../settingsdialog.ui" line="34"/>
         <source>Message delay, ms:</source>
-        <translation>Verzögerung, ms:</translation>
+        <translation>Verzögerung (ms):</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="89"/>
-        <source>OK</source>
-        <translation>OK</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="96"/>
-        <source>Cancel</source>
-        <translation>Abbrechen</translation>
+        <location filename="../settingsdialog.ui" line="86"/>
+        <source>Use standard icons</source>
+        <translation>System-Symbole benutzen</translation>
     </message>
 </context>
 <context>
     <name>StatusIcon</name>
     <message>
-        <location filename="../statusicon.cpp" line="39"/>
+        <location filename="../statusicon.cpp" line="46"/>
         <source>Play</source>
-        <translation>Wiedergeben</translation>
+        <translation>Wiedergabe</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="40"/>
+        <location filename="../statusicon.cpp" line="47"/>
         <source>Pause</source>
-        <translation>Anhalten</translation>
+        <translation>Pause</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="41"/>
+        <location filename="../statusicon.cpp" line="48"/>
         <source>Stop</source>
-        <translation>Stop</translation>
+        <translation>Stopp</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="42"/>
+        <location filename="../statusicon.cpp" line="49"/>
         <source>Next</source>
         <translation>Nächster</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="43"/>
+        <location filename="../statusicon.cpp" line="50"/>
         <source>Previous</source>
         <translation>Vorheriger</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="45"/>
+        <location filename="../statusicon.cpp" line="52"/>
         <source>Exit</source>
         <translation>Beenden</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="96"/>
+        <location filename="../statusicon.cpp" line="127"/>
         <source>Now Playing</source>
         <translation>Aktueller Titel</translation>
     </message>
@@ -77,22 +72,22 @@
     <message>
         <location filename="../statusiconfactory.cpp" line="30"/>
         <source>Status Icon Plugin</source>
-        <translation>Status Icon Plugin</translation>
-    </message>
-    <message>
-        <location filename="../statusiconfactory.cpp" line="50"/>
-        <source>Qmmp Status Icon Plugin</source>
-        <translation>Qmmp Status Icon Plugin</translation>
+        <translation>Statussymbol-Modul</translation>
     </message>
     <message>
         <location filename="../statusiconfactory.cpp" line="51"/>
+        <source>Qmmp Status Icon Plugin</source>
+        <translation>Qmmp Statussymbol-Modul</translation>
+    </message>
+    <message>
+        <location filename="../statusiconfactory.cpp" line="52"/>
         <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../statusiconfactory.cpp" line="49"/>
+        <location filename="../statusiconfactory.cpp" line="50"/>
         <source>About Status Icon Plugin</source>
-        <translation>Über Status Icon Plugin</translation>
+        <translation>Über Statussymbol-Modul</translation>
     </message>
 </context>
 </TS>
