@@ -1,133 +1,122 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="uk">
-<defaultcodec></defaultcodec>
+<!DOCTYPE TS>
+<TS version="2.0" language="uk">
 <context>
     <name>DecoderFFmpegFactory</name>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="44"/>
-        <source>WMA Files</source>
-        <translation>Файли WMA</translation>
-    </message>
-    <message>
-        <location filename="../decoderffmpegfactory.cpp" line="92"/>
+        <location filename="../decoderffmpegfactory.cpp" line="149"/>
         <source>About FFmpeg Audio Plugin</source>
         <translation>Про аудіо-модуль FFmpeg</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="93"/>
+        <location filename="../decoderffmpegfactory.cpp" line="151"/>
         <source>Qmmp FFmpeg Audio Plugin</source>
         <translation>Аудіо-модуль FFmpeg для Qmmp</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="94"/>
-        <source>Suppored formats: WMA</source>
-        <translation>Підтримувані формати: WMA</translation>
-    </message>
-    <message>
-        <location filename="../decoderffmpegfactory.cpp" line="95"/>
+        <location filename="../decoderffmpegfactory.cpp" line="161"/>
         <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="42"/>
-        <source>FFMPEG Plugin</source>
-        <translation>Модуль FFMPEG</translation>
+        <location filename="../decoderffmpegfactory.cpp" line="83"/>
+        <source>FFmpeg Plugin</source>
+        <translation>Модуль FFmpeg</translation>
+    </message>
+    <message>
+        <location filename="../decoderffmpegfactory.cpp" line="85"/>
+        <source>FFmpeg Formats</source>
+        <translation>Формати FFmpeg</translation>
+    </message>
+    <message>
+        <location filename="../decoderffmpegfactory.cpp" line="153"/>
+        <source>Compiled against libavformat-%1.%2.%3 and libavcodec-%4.%5.%6</source>
+        <translation>Зібрано з libavformat-%1.%2.%3 та libavcodec-%4.%5.%6</translation>
     </message>
 </context>
 <context>
     <name>DetailsDialog</name>
     <message>
-        <location filename="../detailsdialog.cpp" line="91"/>
+        <location filename="../detailsdialog.cpp" line="92"/>
         <source>KB</source>
         <translation>Кб</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="108"/>
+        <location filename="../detailsdialog.cpp" line="109"/>
         <source>Hz</source>
         <translation>Гц</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="42"/>
-        <source>ASF Info</source>
-        <translation>Інформація ASF</translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.ui" line="153"/>
+        <location filename="../detailsdialog.ui" line="58"/>
+        <location filename="../detailsdialog.ui" line="75"/>
+        <location filename="../detailsdialog.ui" line="92"/>
+        <location filename="../detailsdialog.ui" line="118"/>
+        <location filename="../detailsdialog.ui" line="135"/>
         <source>-</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="83"/>
+        <location filename="../detailsdialog.ui" line="125"/>
         <source>Bitrate:</source>
         <translation>Бітова частота:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="93"/>
+        <location filename="../detailsdialog.ui" line="82"/>
         <source>File size:</source>
         <translation>Розмір файлу:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="106"/>
+        <location filename="../detailsdialog.ui" line="102"/>
         <source>Channels:</source>
         <translation>Каналів:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="126"/>
+        <location filename="../detailsdialog.ui" line="65"/>
         <source>Sample rate:</source>
         <translation>Дискретизація:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="143"/>
+        <location filename="../detailsdialog.ui" line="48"/>
         <source>Length:</source>
         <translation>Тривалість:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="182"/>
-        <source>WMA Tag</source>
-        <translation>WMA-тег</translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.ui" line="209"/>
-        <source>Save</source>
-        <translation>Зберегти</translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.ui" line="219"/>
+        <location filename="../detailsdialog.ui" line="235"/>
         <source>Track number:</source>
         <translation>Номер треку:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="232"/>
+        <location filename="../detailsdialog.ui" line="222"/>
         <source>Year:</source>
         <translation>Рік:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="242"/>
+        <location filename="../detailsdialog.ui" line="248"/>
         <source>Genre:</source>
         <translation>Жанр:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="252"/>
+        <location filename="../detailsdialog.ui" line="209"/>
         <source>Comment:</source>
         <translation>Коментар:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="262"/>
+        <location filename="../detailsdialog.ui" line="196"/>
         <source>Album:</source>
         <translation>Альбом:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="272"/>
+        <location filename="../detailsdialog.ui" line="183"/>
         <source>Artist:</source>
         <translation>Виконавець:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="282"/>
+        <location filename="../detailsdialog.ui" line="170"/>
         <source>Title:</source>
         <translation>Назва:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="323"/>
+        <location filename="../detailsdialog.ui" line="277"/>
         <source>Close</source>
         <translation>Закрити</translation>
     </message>
@@ -137,7 +126,7 @@
         <translation>Шлях до файлу:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="94"/>
+        <location filename="../detailsdialog.cpp" line="95"/>
         <source>kbps</source>
         <translation>Кб/с</translation>
     </message>
@@ -146,5 +135,68 @@
         <source>Details</source>
         <translation>Інформація</translation>
     </message>
+    <message>
+        <location filename="../detailsdialog.ui" line="42"/>
+        <source>Audio Info</source>
+        <translation>Інфо аудіо</translation>
+    </message>
+    <message>
+        <location filename="../detailsdialog.ui" line="164"/>
+        <source>Metadata</source>
+        <translation>Метадані</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsDialog</name>
+    <message>
+        <location filename="../settingsdialog.ui" line="45"/>
+        <source>Formats</source>
+        <translation>Формати</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="51"/>
+        <source>Windows Media Audio</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="58"/>
+        <source>Monkey&apos;s Audio</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="65"/>
+        <source>True Audio</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="72"/>
+        <source>ALAC (Apple Lossless Audio Codec)</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="79"/>
+        <source>ADTS AAC</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="93"/>
+        <source>MPEG-4 AAC</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="100"/>
+        <source>RealAudio 1.0/2.0</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="13"/>
+        <source>FFmpeg Plugin Settings</source>
+        <translation>Налаштування модуля FFmpeg</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="86"/>
+        <source>MP3 (MPEG audio layer 3)</source>
+        <translation></translation>
+    </message>
 </context>
 </TS>
