@@ -21,7 +21,11 @@
 #include <QtGui>
 #include <taglib/tag.h>
 #include <taglib/fileref.h>
+#include <taglib/flacfile.h>
+#include <taglib/xiphcomment.h>
+#include <taglib/tmap.h>
 
+#include "cueparser.h"
 #include "detailsdialog.h"
 #include "decoder_flac.h"
 #include "decoderflacfactory.h"
@@ -48,44 +52,57 @@ const DecoderProperties DecoderFLACFactory::properties() const
     properties.filter = "*.flac";
     properties.description = tr("FLAC Files");
     //properties.contentType = ;
+    properties.shortName = "flac";
+    properties.protocols = "flac";
     properties.hasAbout = TRUE;
     properties.hasSettings = FALSE;
     return properties;
 }
 
 Decoder *DecoderFLACFactory::create(QObject *parent, QIODevice *input,
-                                    Output *output)
+                                    Output *output, const QString &path)
 {
-    return new DecoderFLAC(parent, this, input, output);
+    return new DecoderFLAC(parent, this, input, output, path);
 }
 
-FileTag *DecoderFLACFactory::createTag(const QString &source)
+QList<FileInfo *> DecoderFLACFactory::createPlayList(const QString &fileName, bool useMetaData)
 {
-    FileTag *ftag = new FileTag();
+    FileInfo *info = new FileInfo(fileName);
 
-    TagLib::FileRef fileRef(source.toLocal8Bit ());
-    TagLib::Tag *tag = fileRef.tag();
+    TagLib::FLAC::File fileRef(fileName.toLocal8Bit ());
+    TagLib::Tag *tag = useMetaData ? fileRef.tag() : 0;
 
     if (tag && !tag->isEmpty())
     {
-        ftag->setValue(FileTag::ALBUM,
-                       QString::fromUtf8(tag->album().toCString(TRUE)).trimmed());
-        ftag->setValue(FileTag::ARTIST,
-                       QString::fromUtf8(tag->artist().toCString(TRUE)).trimmed());
-        ftag->setValue(FileTag::COMMENT,
-                       QString::fromUtf8(tag->comment().toCString(TRUE)).trimmed());
-        ftag->setValue(FileTag::GENRE,
-                       QString::fromUtf8(tag->genre().toCString(TRUE)).trimmed());
-        ftag->setValue(FileTag::TITLE,
-                       QString::fromUtf8(tag->title().toCString(TRUE)).trimmed());
-        ftag->setValue(FileTag::YEAR, tag->year());
-        ftag->setValue(FileTag::TRACK, tag->track());
+        info->setMetaData(Qmmp::ALBUM,
+                          QString::fromUtf8(tag->album().toCString(TRUE)).trimmed());
+        info->setMetaData(Qmmp::ARTIST,
+                          QString::fromUtf8(tag->artist().toCString(TRUE)).trimmed());
+        info->setMetaData(Qmmp::COMMENT,
+                          QString::fromUtf8(tag->comment().toCString(TRUE)).trimmed());
+        info->setMetaData(Qmmp::GENRE,
+                          QString::fromUtf8(tag->genre().toCString(TRUE)).trimmed());
+        info->setMetaData(Qmmp::TITLE,
+                          QString::fromUtf8(tag->title().toCString(TRUE)).trimmed());
+        info->setMetaData(Qmmp::YEAR, tag->year());
+        info->setMetaData(Qmmp::TRACK, tag->track());
     }
 
     if (fileRef.audioProperties())
-        ftag->setValue(FileTag::LENGTH, fileRef.audioProperties()->length());
+        info->setLength(fileRef.audioProperties()->length());
 
-    return ftag;
+    //looking for cuesheet comment
+    TagLib::Ogg::XiphComment *xiph_comment = useMetaData ? fileRef.xiphComment() : 0;
+    QList <FileInfo*> list;
+    if (xiph_comment && xiph_comment->fieldListMap().contains("CUESHEET"))
+    {
+        CUEParser parser(xiph_comment->fieldListMap()["CUESHEET"].toString().toCString(TRUE), fileName);
+        list = parser.createPlayList();
+        delete info;
+    }
+    else
+        list << info;
+    return list;
 }
 
 QObject* DecoderFLACFactory::showDetails(QWidget *parent, const QString &path)
@@ -108,7 +125,7 @@ void DecoderFLACFactory::showAbout(QWidget *parent)
 QTranslator *DecoderFLACFactory::createTranslator(QObject *parent)
 {
     QTranslator *translator = new QTranslator(parent);
-    QString locale = QLocale::system().name();
+    QString locale = Qmmp::systemLanguageID();
     translator->load(QString(":/flac_plugin_") + locale);
     return translator;
 }
