@@ -1,39 +1,40 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="cs">
+<!DOCTYPE TS>
+<TS version="2.0" language="cs">
 <context>
     <name>DecoderMADFactory</name>
     <message>
-        <location filename="../decodermadfactory.cpp" line="67"/>
+        <location filename="../decodermadfactory.cpp" line="87"/>
         <source>MPEG Plugin</source>
         <translation>Modul MPEG</translation>
     </message>
     <message>
-        <location filename="../decodermadfactory.cpp" line="69"/>
+        <location filename="../decodermadfactory.cpp" line="90"/>
         <source>MPEG Files</source>
         <translation>Soubory MPEG</translation>
     </message>
     <message>
-        <location filename="../decodermadfactory.cpp" line="183"/>
+        <location filename="../decodermadfactory.cpp" line="210"/>
         <source>About MPEG Audio Plugin</source>
         <translation>O modulu MPEG</translation>
     </message>
     <message>
-        <location filename="../decodermadfactory.cpp" line="184"/>
+        <location filename="../decodermadfactory.cpp" line="211"/>
         <source>Qmmp MPEG Audio Plugin</source>
         <translation>Vstupní modul Qmmp MPEG</translation>
     </message>
     <message>
-        <location filename="../decodermadfactory.cpp" line="185"/>
+        <location filename="../decodermadfactory.cpp" line="212"/>
         <source>Compiled against libmad version:</source>
         <translation>Zkompilováno s libmad verze</translation>
     </message>
     <message>
-        <location filename="../decodermadfactory.cpp" line="189"/>
+        <location filename="../decodermadfactory.cpp" line="216"/>
         <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decodermadfactory.cpp" line="191"/>
+        <location filename="../decodermadfactory.cpp" line="217"/>
         <source>Source code based on mq3 progect</source>
         <translation>Zdrojový kód je založen na projektu mq3</translation>
     </message>
@@ -41,172 +42,181 @@
 <context>
     <name>DetailsDialog</name>
     <message>
-        <location filename="../detailsdialog.cpp" line="101"/>
+        <location filename="../detailsdialog.cpp" line="113"/>
         <source>kbps</source>
         <translation>kbps</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="103"/>
+        <location filename="../detailsdialog.cpp" line="115"/>
         <source>Hz</source>
         <translation>Hz</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="119"/>
+        <location filename="../detailsdialog.cpp" line="131"/>
         <source>KB</source>
         <translation>KB</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="130"/>
+        <location filename="../detailsdialog.cpp" line="138"/>
+        <location filename="../detailsdialog.cpp" line="142"/>
         <source>Yes</source>
         <translation>Ano</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="132"/>
+        <location filename="../detailsdialog.cpp" line="140"/>
+        <location filename="../detailsdialog.cpp" line="144"/>
         <source>No</source>
         <translation>Ne</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="19"/>
+        <location filename="../detailsdialog.ui" line="20"/>
         <source>Details</source>
         <translation>Podrobnosti</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="90"/>
+        <location filename="../detailsdialog.ui" line="91"/>
         <source>MPEG Info</source>
         <translation>Informace MPEG</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="150"/>
+        <location filename="../detailsdialog.ui" line="151"/>
         <source>File size:</source>
         <translation>Velikost souboru:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="211"/>
+        <location filename="../detailsdialog.ui" line="110"/>
+        <location filename="../detailsdialog.ui" line="127"/>
+        <location filename="../detailsdialog.ui" line="144"/>
+        <location filename="../detailsdialog.ui" line="161"/>
+        <location filename="../detailsdialog.ui" line="178"/>
+        <location filename="../detailsdialog.ui" line="195"/>
+        <location filename="../detailsdialog.ui" line="212"/>
         <source>-</source>
         <translation>-</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="133"/>
+        <location filename="../detailsdialog.ui" line="134"/>
         <source>Sample rate:</source>
         <translation>Vzorkovací frekvence:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="116"/>
+        <location filename="../detailsdialog.ui" line="117"/>
         <source>Bit rate:</source>
         <translation>Datový tok:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="96"/>
-        <source>MPEG level:</source>
-        <translation>MPEG level:</translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.ui" line="167"/>
+        <location filename="../detailsdialog.ui" line="168"/>
         <source>Mode:</source>
         <translation>Režim:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="184"/>
+        <location filename="../detailsdialog.ui" line="185"/>
         <source>Copyright:</source>
         <translation>Copyright:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="201"/>
+        <location filename="../detailsdialog.ui" line="202"/>
         <source>Original:</source>
         <translation>Originál:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="223"/>
+        <location filename="../detailsdialog.cpp" line="157"/>
+        <location filename="../detailsdialog.ui" line="224"/>
         <source>ID3v1 Tag</source>
         <translation>ID3v1 tag</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="461"/>
+        <location filename="../detailsdialog.ui" line="462"/>
         <source>Save</source>
         <translation>Uložit</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="377"/>
+        <location filename="../detailsdialog.ui" line="378"/>
         <source>Track number:</source>
         <translation>Číslo stopy:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="351"/>
+        <location filename="../detailsdialog.ui" line="352"/>
         <source>Year:</source>
         <translation>Rok:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="403"/>
+        <location filename="../detailsdialog.ui" line="404"/>
         <source>Genre:</source>
         <translation>Žánr:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="325"/>
+        <location filename="../detailsdialog.ui" line="326"/>
         <source>Comment:</source>
         <translation>Komentář:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="299"/>
+        <location filename="../detailsdialog.ui" line="300"/>
         <source>Album:</source>
         <translation>Album:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="273"/>
+        <location filename="../detailsdialog.ui" line="274"/>
         <source>Artist:</source>
         <translation>Umělec:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="247"/>
+        <location filename="../detailsdialog.ui" line="248"/>
         <source>Title:</source>
         <translation>Název:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="484"/>
+        <location filename="../detailsdialog.ui" line="485"/>
         <source>Close</source>
         <translation>Zavřít</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="151"/>
+        <location filename="../detailsdialog.cpp" line="163"/>
         <source>ID3v2 Tag</source>
         <translation>ID3v2 tag</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="27"/>
+        <location filename="../detailsdialog.ui" line="28"/>
         <source>File path:</source>
         <translation>Cesta k souboru:</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="155"/>
+        <location filename="../detailsdialog.cpp" line="167"/>
         <source>APE Tag</source>
         <translation>Tag APE</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="54"/>
+        <location filename="../detailsdialog.ui" line="55"/>
         <source>Tag Choice</source>
         <translation>Výběr tagu</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="60"/>
+        <location filename="../detailsdialog.ui" line="61"/>
         <source>ID3v1</source>
         <translation>ID3v1</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="67"/>
+        <location filename="../detailsdialog.ui" line="68"/>
         <source>ID3v2</source>
         <translation>ID3v2</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="74"/>
+        <location filename="../detailsdialog.ui" line="75"/>
         <source>APE</source>
         <translation>APE</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="432"/>
+        <location filename="../detailsdialog.ui" line="97"/>
+        <source>Format:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../detailsdialog.ui" line="433"/>
         <source>Create</source>
         <translation>Vytvořit</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="445"/>
+        <location filename="../detailsdialog.ui" line="446"/>
         <source>Delete</source>
         <translation>Odstranit</translation>
     </message>
@@ -219,35 +229,29 @@
         <translation>Nastavení pluginu MPEG</translation>
     </message>
     <message>
+        <location filename="../settingsdialog.ui" line="47"/>
+        <location filename="../settingsdialog.ui" line="94"/>
         <location filename="../settingsdialog.ui" line="141"/>
         <source>ID3v1</source>
         <translation>ID3v1</translation>
     </message>
     <message>
+        <location filename="../settingsdialog.ui" line="52"/>
+        <location filename="../settingsdialog.ui" line="99"/>
         <location filename="../settingsdialog.ui" line="146"/>
         <source>ID3v2</source>
         <translation>ID3v2</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="192"/>
+        <location filename="../settingsdialog.ui" line="183"/>
         <source>ID3v1 encoding:</source>
         <translation>Kódování ID3v1:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="224"/>
+        <location filename="../settingsdialog.ui" line="206"/>
         <source>ID3v2 encoding:</source>
         <translation>Kódování ID3v2:</translation>
     </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="272"/>
-        <source>OK</source>
-        <translation>OK</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="279"/>
-        <source>Cancel</source>
-        <translation>Zrušit</translation>
-    </message>
     <message>
         <location filename="../settingsdialog.ui" line="19"/>
         <source>Tag Priority</source>
@@ -259,11 +263,15 @@
         <translation>První:</translation>
     </message>
     <message>
+        <location filename="../settingsdialog.ui" line="57"/>
+        <location filename="../settingsdialog.ui" line="104"/>
         <location filename="../settingsdialog.ui" line="151"/>
         <source>APE</source>
         <translation>APE</translation>
     </message>
     <message>
+        <location filename="../settingsdialog.ui" line="62"/>
+        <location filename="../settingsdialog.ui" line="109"/>
         <location filename="../settingsdialog.ui" line="156"/>
         <source>Disabled</source>
         <translation>Zakázáno</translation>
