@@ -20,17 +20,10 @@ public:
 
     // Standard Decoder API
     bool initialize();
-    double lengthInSeconds();
-    void seek(double);
+    qint64 totalTime();
+    void seek(qint64);
     void stop();
 
-    // Equalizer
-    bool isEQSupported() const { return FALSE; }
-    void setEQEnabled(bool) { ; }
-    void setEQGain(int) { ; }
-    void setEQBands(int[10]) { ; }
-
-
 private:
     // thread run function
     void run();
@@ -52,11 +45,11 @@ private:
     OggVorbis_File oggfile;
 
     unsigned int bks;
-    bool done, finish;
+    bool done, m_finish;
     long len, freq, bitrate;
     int chan;
-    unsigned long output_size;
-    double totalTime, seekTime;
+    qint64 output_size;
+    qint64 m_totalTime, seekTime;
 };
 
 
