@@ -1,42 +1,44 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="de">
-<defaultcodec></defaultcodec>
+<!DOCTYPE TS>
+<TS version="2.0" language="de">
 <context>
     <name>DecoderVorbisFactory</name>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="31"/>
+        <location filename="../decodervorbisfactory.cpp" line="50"/>
         <source>Ogg Vorbis Plugin</source>
-        <translation>Ogg Vorbis Plugin</translation>
+        <translation>Ogg-Vorbis-Modul</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="33"/>
+        <location filename="../decodervorbisfactory.cpp" line="53"/>
         <source>Ogg Vorbis Files</source>
-        <translation>Ogg Vorbis Dateien</translation>
+        <translation>Ogg-Vorbis-Dateien</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="90"/>
+        <location filename="../decodervorbisfactory.cpp" line="113"/>
         <source>About Ogg Vorbis Audio Plugin</source>
-        <translation>Über Ogg Vorbis Audio Plugin</translation>
+        <translation>Über Ogg-Vorbis-Audio-Modul</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="91"/>
+        <location filename="../decodervorbisfactory.cpp" line="114"/>
         <source>Qmmp Ogg Vorbis Audio Plugin</source>
-        <translation>Qmmp Ogg Vorbis Audio Plugin</translation>
+        <translation>Qmmp Ogg-Vorbis-Audio-Modul</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="92"/>
+        <location filename="../decodervorbisfactory.cpp" line="115"/>
         <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
-        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
+        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="94"/>
+        <location filename="../decodervorbisfactory.cpp" line="116"/>
         <source>Source code based on mq3 progect</source>
-        <translation>Quellcode basiert auf mq3-Projekt</translation>
+        <translation>Quellcode basiert auf dem mq3-Projekt</translation>
     </message>
 </context>
 <context>
     <name>DetailsDialog</name>
     <message>
+        <location filename="../detailsdialog.cpp" line="65"/>
+        <location filename="../detailsdialog.cpp" line="67"/>
         <location filename="../detailsdialog.cpp" line="69"/>
         <source>kbps</source>
         <translation>kbps</translation>
@@ -62,6 +64,12 @@
         <translation>Dateigröße:</translation>
     </message>
     <message>
+        <location filename="../detailsdialog.ui" line="66"/>
+        <location filename="../detailsdialog.ui" line="76"/>
+        <location filename="../detailsdialog.ui" line="93"/>
+        <location filename="../detailsdialog.ui" line="110"/>
+        <location filename="../detailsdialog.ui" line="170"/>
+        <location filename="../detailsdialog.ui" line="177"/>
         <location filename="../detailsdialog.ui" line="197"/>
         <source>-</source>
         <translation>-</translation>
@@ -104,7 +112,7 @@
     <message>
         <location filename="../detailsdialog.ui" line="336"/>
         <source>Artist:</source>
-        <translation>Künstler:</translation>
+        <translation>Interpret:</translation>
     </message>
     <message>
         <location filename="../detailsdialog.ui" line="346"/>
@@ -124,7 +132,7 @@
     <message>
         <location filename="../detailsdialog.ui" line="42"/>
         <source>Ogg Vorbis Info</source>
-        <translation>Ogg Vorbis Info</translation>
+        <translation>Ogg-Vorbis-Info</translation>
     </message>
     <message>
         <location filename="../detailsdialog.ui" line="83"/>
@@ -154,12 +162,12 @@
     <message>
         <location filename="../detailsdialog.ui" line="214"/>
         <source>Nominal:</source>
-        <translation>Soll:</translation>
+        <translation>Nominell:</translation>
     </message>
     <message>
         <location filename="../detailsdialog.ui" line="246"/>
         <source>Ogg Vorbis Tag</source>
-        <translation>Ogg-Vorbis tag</translation>
+        <translation>Ogg-Vorbis-Tag</translation>
     </message>
 </context>
 </TS>
