@@ -1,34 +1,35 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="ru">
+<!DOCTYPE TS>
+<TS version="2.0" language="ru">
 <context>
     <name>DecoderVorbisFactory</name>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="31"/>
+        <location filename="../decodervorbisfactory.cpp" line="50"/>
         <source>Ogg Vorbis Plugin</source>
         <translation>Модуль Ogg Vorbis</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="33"/>
+        <location filename="../decodervorbisfactory.cpp" line="53"/>
         <source>Ogg Vorbis Files</source>
         <translation>Файлы Ogg Vorbis</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="90"/>
+        <location filename="../decodervorbisfactory.cpp" line="113"/>
         <source>About Ogg Vorbis Audio Plugin</source>
         <translation>Об аудио-модуле Ogg Vorbis</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="91"/>
+        <location filename="../decodervorbisfactory.cpp" line="114"/>
         <source>Qmmp Ogg Vorbis Audio Plugin</source>
         <translation>Аудио-модуль Ogg Vorbis для Qmmp</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="92"/>
+        <location filename="../decodervorbisfactory.cpp" line="115"/>
         <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="94"/>
+        <location filename="../decodervorbisfactory.cpp" line="116"/>
         <source>Source code based on mq3 progect</source>
         <translation>Исходный код основан на проекте mq3</translation>
     </message>
@@ -86,6 +87,12 @@
         <translation>Закрыть</translation>
     </message>
     <message>
+        <location filename="../detailsdialog.ui" line="66"/>
+        <location filename="../detailsdialog.ui" line="76"/>
+        <location filename="../detailsdialog.ui" line="93"/>
+        <location filename="../detailsdialog.ui" line="110"/>
+        <location filename="../detailsdialog.ui" line="170"/>
+        <location filename="../detailsdialog.ui" line="177"/>
         <location filename="../detailsdialog.ui" line="197"/>
         <source>-</source>
         <translation></translation>
@@ -146,6 +153,8 @@
         <translation>Оgg Vorbis-тег</translation>
     </message>
     <message>
+        <location filename="../detailsdialog.cpp" line="65"/>
+        <location filename="../detailsdialog.cpp" line="67"/>
         <location filename="../detailsdialog.cpp" line="69"/>
         <source>kbps</source>
         <translation>Кб/с</translation>
@@ -153,7 +162,7 @@
     <message>
         <location filename="../detailsdialog.cpp" line="70"/>
         <source>KB</source>
-        <translation>Кб</translation>
+        <translation>КБ</translation>
     </message>
     <message>
         <location filename="../detailsdialog.ui" line="13"/>
