@@ -25,51 +25,65 @@ class OutputALSA;
 
 
 #include <QObject>
-extern "C" {
+extern "C"
+{
 #include <alsa/asoundlib.h>
 }
 
 #include <qmmp/output.h>
+#include <qmmp/volumecontrol.h>
 
 
 class OutputALSA : public Output
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-    OutputALSA(QObject * parent = 0, bool useVolume = TRUE);
+    OutputALSA(QObject * parent = 0);
     ~OutputALSA();
 
     bool initialize();
-    bool isInitialized() const { return m_inited; }
-    void uninitialize();
-    void configure(long, int, int, int);
-    void stop();
+    void configure(quint32, int, int);
+    qint64 latency();
     void pause();
-    long written();
-    long latency();
-    void seek(long);
-    void setVolume(int l, int r);
-    void volume(int *l, int *r);
 
 private:
-    // thread run function
-    void run();
+    //output api
+    qint64 writeAudio(unsigned char *data, qint64 maxSize);
+    void flush();
 
     // helper functions
     void reset();
-    void status();
     long alsa_write(unsigned char *data, long size);
+    void uninitialize();
 
-    bool m_inited, m_pause, m_play, m_userStop;
-    long m_totalWritten, m_currentSeconds, m_bps;
-    int m_rate, m_frequency, m_channels, m_precision;
+    bool m_inited;
+    bool m_use_mmap;
     //alsa
     snd_pcm_t *pcm_handle;
     char *pcm_name;
-    //alsa
     snd_pcm_uframes_t m_chunk_size;
     size_t m_bits_per_frame;
+    //prebuffer
+    uchar *m_prebuf;
+    qint64 m_prebuf_size;
+    qint64 m_prebuf_fill;
+    bool m_pause;
+    bool m_can_pause;
+};
 
+class VolumeControlALSA : public VolumeControl
+{
+    Q_OBJECT
+public:
+    VolumeControlALSA(QObject *parent = 0);
+    ~VolumeControlALSA();
+
+    void setVolume(int left, int right) ;
+
+protected:
+    void volume(int *left, int *right);
+
+private:
     //alsa mixer
     int setupMixer(QString card, QString device);
     void parseMixerName(char *str, char **name, int *index);
