@@ -1,26 +1,27 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="de">
+<!DOCTYPE TS>
+<TS version="2.0" language="de">
 <context>
     <name>OutputJACKFactory</name>
     <message>
         <location filename="../outputjackfactory.cpp" line="30"/>
         <source>JACK Plugin</source>
-        <translation>JACK Plugin</translation>
+        <translation>JACK-Modul</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="47"/>
+        <location filename="../outputjackfactory.cpp" line="53"/>
         <source>About Jack Output Plugin</source>
-        <translation>Über Jack Output Plugin</translation>
+        <translation>Über JACK-Ausgabe-Modul</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="48"/>
+        <location filename="../outputjackfactory.cpp" line="54"/>
         <source>Qmmp Jack Output Plugin</source>
-        <translation>Qmmp Jack Output Plugin</translation>
+        <translation>Qmmp JACK-Ausgabe-Modul</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="49"/>
+        <location filename="../outputjackfactory.cpp" line="55"/>
         <source>Writen by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
-        <translation>Autor: Jurij Žuravljov &lt;slalkerg@gmail.com&gt;</translation>
+        <translation>Autor: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</translation>
     </message>
 </context>
 </TS>
