@@ -1,24 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="de">
+<!DOCTYPE TS>
+<TS version="2.0" language="de">
 <context>
     <name>OutputPulseAudioFactory</name>
     <message>
         <location filename="../outputpulseaudiofactory.cpp" line="30"/>
         <source>PulseAudio Plugin</source>
-        <translation>PulseAudio Plugin</translation>
+        <translation>PulseAudio-Modul</translation>
     </message>
     <message>
-        <location filename="../outputpulseaudiofactory.cpp" line="48"/>
+        <location filename="../outputpulseaudiofactory.cpp" line="54"/>
         <source>About PulseAudio Output Plugin</source>
-        <translation>Über PulseAudio Output Plugin</translation>
+        <translation>Über PulseAudio-Ausgabe-Modul</translation>
     </message>
     <message>
-        <location filename="../outputpulseaudiofactory.cpp" line="49"/>
+        <location filename="../outputpulseaudiofactory.cpp" line="55"/>
         <source>Qmmp PulseAudio Output Plugin</source>
-        <translation>Qmmp PulseAudio Output Plugin</translation>
+        <translation>Qmmp PulseAudio-Ausgabe-Modul</translation>
     </message>
     <message>
-        <location filename="../outputpulseaudiofactory.cpp" line="50"/>
+        <location filename="../outputpulseaudiofactory.cpp" line="56"/>
         <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
