@@ -22,6 +22,7 @@
 #include <QDir>
 #include <QApplication>
 
+#include "qmmp.h"
 #include "effectfactory.h"
 #include "constants.h"
 #include "effect.h"
@@ -33,15 +34,14 @@ Effect::Effect(QObject *parent)
 Effect::~Effect()
 {}
 
-void Effect::configure(ulong freq, int chan, int res)
+void Effect::configure(quint32 freq, int chan, int res)
 {
     m_freq = freq;
     m_chan = chan;
     m_res = res;
-
 }
 
-ulong Effect::frequency()
+quint32 Effect::sampleRate()
 {
     return m_freq;
 }
@@ -51,7 +51,7 @@ int Effect::channels()
     return m_chan;
 }
 
-int Effect::resolution()
+int Effect::bitsPerSample()
 {
     return m_res;
 }
@@ -66,9 +66,8 @@ static void checkFactories()
         files.clear();
         factories = new QList<EffectFactory *>;
 
-        QDir pluginsDir (qApp->applicationDirPath());
-        pluginsDir.cdUp();
-        pluginsDir.cd("./"LIB_DIR"/qmmp/Effect");
+         QDir pluginsDir (Qmmp::pluginsPath());
+        pluginsDir.cd("Effect");
         foreach (QString fileName, pluginsDir.entryList(QDir::Files))
         {
             QPluginLoader loader(pluginsDir.absoluteFilePath(fileName));
@@ -123,9 +122,9 @@ void Effect::setEnabled(EffectFactory* factory, bool enable)
     if(!factories->contains(factory))
         return;
 
-    QString name = files.at(factories->indexOf(factory)).section('/',-1);
-    QSettings settings ( QDir::homePath() +"/.qmmp/qmmprc", QSettings::IniFormat );
-    QStringList effList = settings.value("Effect/plugin_files").toStringList();
+    QString name = factory->properties().shortName;
+    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
+    QStringList effList = settings.value("Effect/enabled_plugins").toStringList();
 
     if(enable)
     {
@@ -134,7 +133,7 @@ void Effect::setEnabled(EffectFactory* factory, bool enable)
     }
     else
         effList.removeAll(name);
-    settings.setValue("Effect/plugin_files", effList);
+    settings.setValue("Effect/enabled_plugins", effList);
 }
 
 bool Effect::isEnabled(EffectFactory* factory)
@@ -142,9 +141,9 @@ bool Effect::isEnabled(EffectFactory* factory)
     checkFactories();
     if(!factories->contains(factory))
         return FALSE;
-    QString name = files.at(factories->indexOf(factory)).section('/',-1);
-    QSettings settings ( QDir::homePath() +"/.qmmp/qmmprc", QSettings::IniFormat );
-    QStringList effList = settings.value("Effect/plugin_files").toStringList();
+    QString name = factory->properties().shortName;
+    QSettings settings ( Qmmp::configFile(), QSettings::IniFormat );
+    QStringList effList = settings.value("Effect/enabled_plugins").toStringList();
     return effList.contains(name);
 }
 
