@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007 by Ilya Kotov                                      *
+ *   Copyright (C) 2007-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,62 +24,78 @@
 #include <QList>
 #include <QStringList>
 
-
-/**
-    @author Ilya Kotov <forkotov02@hotmail.ru>
-*/
-
 class EffectFactory;
 
+/*! @brief The Effect class provides the base interface class of audio effects.
+ * @author Ilya Kotov <forkotov02@hotmail.ru>
+ */
 class Effect : public QObject
 {
     Q_OBJECT
 public:
+    /*!
+     * Object contsructor.
+     * @param parent Parent object.
+     */
     Effect(QObject *parent = 0);
-
+    /*!
+     * Destructor.
+     */
     virtual ~Effect();
-
-    /*/*!
+    /*!
      * Adds effect to the input data pointer \b in_data with the size \b size.
      * Result is stored in the output data \b out_data.
-     * Return value is the size of the output data. Output data size should not be more then \b size.
+     * Return value is the size of the output data.
      * Subclass should implement this function.
      */
     virtual ulong process(char *in_data, const ulong size, char **out_data) = 0;
-
-    //virtual const ulong process(char *in_data, const ulong size, char *out_data) = 0;
-    //virtual bool process(char *in_data, char *out_data, const ulong maxsize, ulong &rbytes, ulong &wbytes) = 0;
-
-
-    virtual void configure(ulong freq, int chan, int res);
-
     /*!
-     * Returns frequency.
-     * This function should be reimplemented if subclass changes default samplerate.
+     * Prepares object for usage.
+     * Subclasses that reimplement this function must call the base implementation.
+     * @param freq Sample rate.
+     * @param chan Number of channels.
+     * @param res Bits per sample.
      */
-    virtual ulong frequency();
-
+    virtual void configure(quint32 freq, int chan, int res);
     /*!
-     * Returns channel number.
-     * This function should be reimplemented if subclass changes default channel number.
+     * Returns samplerate.
      */
-    virtual int channels();
-
+    quint32 sampleRate();
     /*!
-     * Returns resolution.
-     * This function should be reimplemented if subclass changes default resolution.
+     * Returns channels number.
+     */
+    int channels();
+    /*!
+     * Returns bits per sample.
+     */
+    int bitsPerSample();
+    /*!
+     * Creates a list of enabled effects.
+     * @param parent Parent object of all created Effect objects.
      */
-    virtual int resolution();
-
-
     static QList<Effect*> create(QObject *parent);
+    /*!
+     * Returns a list of effect factories.
+     */
     static QList<EffectFactory*> *effectFactories();
+    /*!
+     * Returns a list of effect plugin file names.
+     */
     static QStringList effectFiles();
+    /*!
+     * Sets whether the effect plugin is enabled.
+     * @param factory Effect plugin factory.
+     * @param enable Plugin enable state (\b true - enable, \b false - disable)
+     */
     static void setEnabled(EffectFactory* factory, bool enable = TRUE);
+    /*!
+     * Returns \b true if input plugin is enabled, otherwise returns \b false
+     * @param factory Effect plugin factory.
+     */
     static bool isEnabled(EffectFactory* factory);
 
 private:
-    ulong m_freq;
+    quint32 m_freq;
     int m_chan;
     int m_res;
 };
