@@ -28,6 +28,8 @@
 #include "constants.h"
 #include "streamreader.h"
 #include "effect.h"
+#include "statehandler.h"
+#include "volumecontrol.h"
 
 #include "soundcore.h"
 
@@ -48,104 +50,100 @@ SoundCore::SoundCore(QObject *parent)
     m_preamp = 0;
     m_vis = 0;
     m_parentWidget = 0;
+    m_factory = 0;
     for (int i = 1; i < 10; ++i)
         m_bands[i] = 0;
-    m_error = NoError;
-    m_output = Output::create(this);
-    if (!m_output)
-    {
-        m_error = DecoderError;
-        qWarning("SoundCore: unable to create output");
-    }
-    connect(m_output, SIGNAL(stateChanged(const OutputState&)),
-            SIGNAL(outputStateChanged(const OutputState&)));
-
-    QList<OutputFactory*> *outputFactories = Output::outputFactories();
-    foreach(OutputFactory* of, *outputFactories)
-    qApp->installTranslator(of->createTranslator(this));
-
-    QList<DecoderFactory*> *decoderFactories = Decoder::decoderFactories();
-    foreach(DecoderFactory* df, *decoderFactories)
-    qApp->installTranslator(df->createTranslator(this));
-
-    Effect::effectFactories();
+    m_handler = new StateHandler(this);
+    //StateHandler::instance() = 0;
+    //StateHandler::m_instance = m_handler;
+    connect(m_handler, SIGNAL(elapsedChanged(qint64)), SIGNAL(elapsedChanged(qint64)));
+    connect(m_handler, SIGNAL(bitrateChanged(int)), SIGNAL(bitrateChanged(int)));
+    connect(m_handler, SIGNAL(frequencyChanged(quint32)), SIGNAL(frequencyChanged(quint32)));
+    connect(m_handler, SIGNAL(precisionChanged(int)), SIGNAL(precisionChanged(int)));
+    connect(m_handler, SIGNAL(channelsChanged(int)), SIGNAL(channelsChanged(int)));
+    connect(m_handler, SIGNAL(metaDataChanged ()), SIGNAL(metaDataChanged ()));
+    connect(m_handler, SIGNAL(stateChanged (Qmmp::State)), SIGNAL(stateChanged(Qmmp::State)));
+    m_volumeControl = VolumeControl::create(this);
+    connect(m_volumeControl, SIGNAL(volumeChanged(int, int)), SIGNAL(volumeChanged(int, int)));
 }
 
 
 SoundCore::~SoundCore()
-{}
+{
+    stop();
+}
 
 bool SoundCore::play(const QString &source)
 {
     stop();
-    if (source.isEmpty())
+    m_source = source;
+    if (m_handler->state() != Qmmp::Stopped) //clear error state
+        m_handler->dispatch(Qmmp::Stopped);
+
+    m_handler->dispatch(Qmmp::Buffering); //buffering state
+
+    QUrl url;
+    if (source.contains("://")) //url
+        url = source;
+    else if (QFile::exists(source))
+        url = QUrl::fromLocalFile(source);
+    else
     {
-        m_error = DecoderError;
+        qDebug("SoundCore: file doesn't exist");
+        m_handler->dispatch(Qmmp::NormalError);
         return FALSE;
     }
-    if (source.left(4) == "http")
+
+    m_factory = Decoder::findByURL(url);
+    if (m_factory)
+        return decode();
+
+    if (url.scheme() == "file")
+    {
+        if ((m_factory = Decoder::findByPath(m_source)))
+        {
+            m_input = new QFile(m_source);
+            if (!m_input->open(QIODevice::ReadOnly))
+            {
+                qDebug("SoundCore: cannot open input");
+                stop();
+                m_handler->dispatch(Qmmp::NormalError);
+                return FALSE;
+            }
+            return decode();
+        }
+        else
+        {
+            qWarning("SoundCore: unsupported fileformat");
+            stop();
+            m_handler->dispatch(Qmmp::NormalError);
+            return FALSE;
+        }
+    }
+    if (url.scheme() == "http")
     {
         m_input = new StreamReader(source, this);
         connect(m_input, SIGNAL(bufferingProgress(int)), SIGNAL(bufferingProgress(int)));
-        connect(m_input, SIGNAL(titleChanged(const QString&)),
-                SIGNAL(titleChanged(const QString&)));
         connect(m_input, SIGNAL(readyRead()),SLOT(decode()));
-    }
-    else
-        m_input = new QFile(source);
-
-    m_error = OutputError;
-    if (!m_output)
-    {
-        m_output = Output::create(this);
-        if (!m_output)
-        {
-            qWarning("SoundCore: unable to create output");
-            return FALSE;
-        }
-        connect(m_output, SIGNAL(stateChanged(const OutputState&)),
-                SIGNAL(outputStateChanged(const OutputState&)));
-        connect(m_input, SIGNAL(readyRead()),SLOT(read()));
-    }
-    if (! m_output->initialize())
-        return FALSE;
-
-    m_error = DecoderError;
-
-    Visual *visual = 0;
-    foreach(visual, m_visuals)
-    m_output->addVisual(visual);
-
-    VisualFactory* factory;
-    foreach(factory, *Visual::visualFactories())
-    {
-        if (Visual::isEnabled(factory))
-            m_output->addVisual(factory, m_parentWidget);
-    }
-
-    m_source = source;
-    if (source.left(4) != "http")
-        return decode();
-    else
         qobject_cast<StreamReader *>(m_input)->downloadFile();
-    return TRUE;
-}
-
-uint SoundCore::error()
-{
-    return m_error;
+        return TRUE;
+    }
+    qWarning("SoundCore: unsupported fileformat");
+    stop();
+    m_handler->dispatch(Qmmp::NormalError);
+    return FALSE;
 }
 
 void SoundCore::stop()
 {
-    if (m_block)
-        return;
-    m_paused = FALSE;
-    if (m_decoder && m_decoder->isRunning())
+    m_factory = 0;
+    m_source.clear();
+    if (m_decoder /*&& m_decoder->isRunning()*/)
     {
         m_decoder->mutex()->lock ();
         m_decoder->stop();
         m_decoder->mutex()->unlock();
+        //m_decoder->stateHandler()->dispatch(Qmmp::Stopped);
     }
     if (m_output)
     {
@@ -171,12 +169,12 @@ void SoundCore::stop()
         m_decoder->wait();
     if (m_output)
         m_output->wait();
-    if (m_output && m_output->isInitialized())
-    {
-        m_output->uninitialize();
-    }
 
-    //display->setTime(0);
+    if (m_output)
+    {
+        delete m_output;
+        m_output = 0;
+    }
     if (m_decoder)
     {
         delete m_decoder;
@@ -184,29 +182,13 @@ void SoundCore::stop()
     }
     if (m_input)
     {
-        delete m_input;
+        m_input->deleteLater();
         m_input = 0;
     }
-    // recreate output
-    if (m_update && m_output)
-    {
-        delete m_output;
-        m_output = 0;
-        m_update = FALSE;
-        m_output = Output::create(this);
-        if (!m_output)
-        {
-            qWarning("SoundCore: unable to create output");
-        }
-        VisualFactory* factory;
-        foreach(factory, *Visual::visualFactories())
-        {
-            if (Visual::isEnabled(factory))
-                m_output->addVisual(factory, m_parentWidget);
-        }
-        connect(m_output, SIGNAL(stateChanged(const OutputState&)),
-                SIGNAL(outputStateChanged(const OutputState&)));
-    }
+    //update VolumeControl
+    delete m_volumeControl;
+    m_volumeControl = VolumeControl::create(this);
+    connect(m_volumeControl, SIGNAL(volumeChanged(int, int)), SIGNAL(volumeChanged(int, int)));
 }
 
 void SoundCore::pause()
@@ -217,11 +199,16 @@ void SoundCore::pause()
         m_output->pause();
         m_output->mutex()->unlock();
     }
+    else if (m_decoder)
+    {
+        m_decoder->mutex()->lock ();
+        m_decoder->pause();
+        m_decoder->mutex()->unlock();
+    }
 
     // wake up threads
     if (m_decoder)
     {
-        m_paused = !m_paused;
         m_decoder->mutex()->lock ();
         m_decoder->cond()->wakeAll();
         m_decoder->mutex()->unlock();
@@ -235,13 +222,10 @@ void SoundCore::pause()
     }
 }
 
-void SoundCore::seek(int pos)
+void SoundCore::seek(qint64 pos)
 {
     if (m_output && m_output->isRunning())
     {
-        /*m_output->recycler()->mutex()->lock ();
-        m_output->recycler()->clear ();
-        m_output->recycler()->mutex()->unlock ();*/
         m_output->mutex()->lock ();
         m_output->seek(pos);
         m_output->mutex()->unlock();
@@ -252,28 +236,25 @@ void SoundCore::seek(int pos)
             m_decoder->mutex()->unlock();
         }
     }
+    else if (m_decoder)
+    {
+        m_decoder->mutex()->lock ();
+        m_decoder->seek(pos);
+        m_decoder->mutex()->unlock();
+    }
 }
 
-int SoundCore::length()
+const QString SoundCore::url()
 {
-    if (m_decoder)
-        return int(m_decoder->lengthInSeconds());
-    return 0;
+    return m_source;
 }
 
-bool SoundCore::isInitialized()
+qint64 SoundCore::totalTime() const
 {
-    if (m_decoder)
-        return TRUE;
-    return FALSE;
+    return  (m_decoder) ? m_decoder->totalTime() : 0;
 }
 
-bool SoundCore::isPaused()
-{
-    return m_paused;
-}
-
-void SoundCore::setEQ(int bands[10], const int &preamp)
+void SoundCore::setEQ(double bands[10], double preamp)
 {
     for (int i = 0; i < 10; ++i)
         m_bands[i] = bands[i];
@@ -301,137 +282,150 @@ void SoundCore::setEQEnabled(bool on)
 
 void SoundCore::setVolume(int L, int R)
 {
-    QSettings settings(QDir::homePath()+"/.qmmp/qmmprc", QSettings::IniFormat);
-    bool sofVolume = settings.value("Volume/software_volume", FALSE).toBool();
-    if (sofVolume)
-    {
-        L = qMin(L,100);
-        R = qMin(R,100);
-        L = qMax(L,0);
-        R = qMax(R,0);
-        settings.setValue("Volume/left", L);
-        settings.setValue("Volume/right", R);
-        if (m_decoder)
-            m_decoder->setVolume(L,R);
-        if (m_output)
-            m_output->checkSoftwareVolume();
-    }
-    else if (m_output)
-        m_output->setVolume(L,R);
+    m_volumeControl->setVolume(L, R);
 }
 
-void SoundCore::volume(int *left, int *right)
+int SoundCore::leftVolume()
 {
-    QSettings settings(QDir::homePath()+"/.qmmp/qmmprc", QSettings::IniFormat);
-    bool sofVolume = settings.value("Volume/software_volume", FALSE).toBool();
-    if (sofVolume)
-    {
-        *left = settings.value("Volume/left", 0).toInt();
-        *right = settings.value("Volume/right", 0).toInt();
-    }
-    else if (m_output)
-        m_output->volume(left,right);
-    return;
+    return m_volumeControl->left();
 }
 
-void SoundCore::updateConfig()
+int SoundCore::rightVolume()
 {
-    m_update = TRUE;
-    if (isInitialized())
-        return;
-    stop();
+    return m_volumeControl->right();
 }
 
-void SoundCore::addVisualization(Visual *visual)
+void SoundCore::setSoftwareVolume(bool b)
 {
-    if (m_visuals.indexOf (visual) == -1)
-    {
-        m_visuals.append(visual);
-        if (m_output)
-            m_output->addVisual(visual);
-    }
+    SoftwareVolume::setEnabled(b);
+    if (m_decoder)
+        m_decoder->mutex()->lock();
+    delete m_volumeControl;
+    m_volumeControl = VolumeControl::create(this);
+    connect(m_volumeControl, SIGNAL(volumeChanged(int, int)), SIGNAL(volumeChanged(int, int)));
+    if (m_decoder)
+        m_decoder->mutex()->unlock();
+}
+
+bool SoundCore::softwareVolume()
+{
+    return SoftwareVolume::instance() != 0;
+}
+
+qint64 SoundCore::elapsed()
+{
+    return  m_handler->elapsed();
+}
+
+int SoundCore::bitrate()
+{
+    return  m_handler->bitrate();
+}
+
+quint32 SoundCore::frequency()
+{
+    return  m_handler->frequency();
+}
+
+int SoundCore::precision() //TODO rename
+{
+    return  m_handler->precision();
+}
+
+int SoundCore::channels()
+{
+    return  m_handler->channels();
+}
+
+Qmmp::State SoundCore::state() const
+{
+    return  m_handler->state();
+}
+
+QMap <Qmmp::MetaData, QString> SoundCore::metaData()
+{
+    return m_handler->metaData();
+}
+
+QString SoundCore::metaData(Qmmp::MetaData key)
+{
+    return m_handler->metaData(key);
 }
 
 bool SoundCore::decode()
 {
-    if (! m_decoder)
+    if (!m_factory)
     {
-        m_block = TRUE;
-        qDebug ("SoundCore: creating decoder");
-        m_decoder = Decoder::create(this, m_source, m_input, m_output);
-
-        if (! m_decoder)
+        if (!m_input->open(QIODevice::ReadOnly))
         {
-            qWarning("SoundCore: unsupported fileformat");
-            m_block = FALSE;
-            stop();
-            emit decoderStateChanged(DecoderState(DecoderState::Error));
+            qDebug("SoundCore:: cannot open input");
+            m_handler->dispatch(Qmmp::NormalError);
             return FALSE;
         }
-        qDebug ("ok");
-        m_decoder->setBlockSize(globalBlockSize);
-        connect(m_decoder, SIGNAL(stateChanged(const DecoderState&)),
-                SIGNAL(decoderStateChanged(const DecoderState&)));
-        setEQ(m_bands, m_preamp);
-        setEQEnabled(m_useEQ);
+        if (!(m_factory = Decoder::findByMime(qobject_cast<StreamReader *>(m_input)->contentType())))
+            if (!(m_factory = Decoder::findByContent(m_input)))
+            {
+                m_handler->dispatch(Qmmp::NormalError);
+                return FALSE;
+            }
     }
-    qDebug("SoundCore: decoder was created successfully");
+    if (!m_factory->properties().noOutput)
+    {
+        m_output = Output::create(this);
+        if (!m_output)
+        {
+            qWarning("SoundCore: unable to create output");
+            m_handler->dispatch(Qmmp::FatalError);
+            return FALSE;
+        }
+        if (!m_output->initialize())
+        {
+            qWarning("SoundCore: unable to initialize output");
+            delete m_output;
+            m_output = 0;
+            m_handler->dispatch(Qmmp::FatalError);
+            return FALSE;
+        }
+    }
+    m_decoder = m_factory->create(this, m_input, m_output, m_source);
+    if (!m_decoder)
+    {
+        qWarning("SoundCore: unsupported fileformat");
+        m_block = FALSE;
+        stop();
+        m_handler->dispatch(Qmmp::NormalError);
+        return FALSE;
+    }
+    m_decoder->setStateHandler(m_handler);
+    setEQ(m_bands, m_preamp);
+    setEQEnabled(m_useEQ);
+    qDebug ("ok");
+    connect(m_decoder, SIGNAL(playbackFinished()), SIGNAL(finished()));
+    if (m_output)
+        m_output->setStateHandler(m_decoder->stateHandler());
 
     if (m_decoder->initialize())
     {
-        m_output->start();
+        if (QFile::exists(m_source)) //send metadata for local files
+        {
+            QList <FileInfo *> list = m_factory->createPlayList(m_source, TRUE);
+            if (!list.isEmpty())
+            {
+                m_handler->dispatch(list[0]->metaData());
+                while (!list.isEmpty())
+                    delete list.takeFirst();
+            }
+        }
+
+        if (m_output)
+            m_output->start();
         m_decoder->start();
-        m_error = NoError;
-        m_block = FALSE;
         return TRUE;
     }
     stop();
-    m_block = FALSE;
     return FALSE;
 }
 
-void SoundCore::showVisualization(QWidget *parent)
-{
-    if (!m_parentWidget)
-    {
-        m_parentWidget = parent;
-        if (!m_output)
-            return;
-        VisualFactory* factory;
-        foreach(factory, *Visual::visualFactories())
-        {
-            if (Visual::isEnabled(factory))
-                m_output->addVisual(factory, m_parentWidget);
-        }
-    }
-}
-
-void SoundCore::addVisual(VisualFactory *factory, QWidget *parent)
-{
-    if (m_output)
-        m_output->addVisual(factory, parent);
-    else
-        Visual::setEnabled(factory, TRUE);
-}
-
-void SoundCore::removeVisual(VisualFactory *factory)
-{
-    if (m_output)
-        m_output->removeVisual(factory);
-    else
-        Visual::setEnabled(factory, FALSE);
-}
-
-void SoundCore::removeVisual(Visual *visual)
-{
-    if (m_visuals.indexOf (visual) != -1)
-    {
-        m_visuals.removeAll(visual);
-        if (m_output)
-            m_output->removeVisual(visual);
-    }
-}
-
 SoundCore* SoundCore::instance()
 {
     return m_instance;
