@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,10 +33,13 @@
 #include <qmmp/visualfactory.h>
 #include <qmmp/effectfactory.h>
 #include <qmmp/effect.h>
+#include <qmmp/soundcore.h>
 #include <qmmpui/generalfactory.h>
 #include <qmmpui/general.h>
 #include <qmmpui/generalhandler.h>
 #include <qmmpui/filedialog.h>
+#include <qmmpui/mediaplayer.h>
+#include <qmmpui/playlistmodel.h>
 
 
 #include "skin.h"
@@ -68,11 +71,13 @@ ConfigDialog::ConfigDialog ( QWidget *parent )
     connect (ui.pluginsTab, SIGNAL(currentChanged(int)), SLOT(updateButtons()));
     connect (ui.fileDialogComboBox, SIGNAL (currentIndexChanged (int)), SLOT(updateDialogButton(int)));
     connect (ui.fdInformationButton, SIGNAL (clicked()), SLOT(showFileDialogInfo()));
+    connect (ui.skinInstallButton, SIGNAL (clicked()), SLOT(installSkin()));
+    connect (ui.skinReloadButton, SIGNAL (clicked()), SLOT(loadSkins()));
+    connect (ui.listWidget, SIGNAL (itemClicked (QListWidgetItem *)), this, SLOT (changeSkin()));
     ui.listWidget->setIconSize (QSize (69,29));
     m_skin = Skin::getPointer();
     readSettings();
     m_reader = new SkinReader(this);
-    m_reader->generateThumbs();
     loadSkins();
     loadPluginsInfo();
     loadFonts();
@@ -93,25 +98,24 @@ ConfigDialog::~ConfigDialog()
 
 void ConfigDialog::readSettings()
 {
-    QSettings settings (QDir::homePath() +"/.qmmp/qmmprc", QSettings::IniFormat);
-    ui.formatLineEdit->setText(
-        settings.value ("PlayList/title_format", "%p - %t").toString());
-    ui.metadataCheckBox->setChecked(
-        settings.value ("PlayList/load_metadata", TRUE).toBool());
-    ui.underscoresCheckBox->setChecked(settings.value ("PlayList/convert_underscore", TRUE).toBool());
-    ui.per20CheckBox->setChecked(settings.value ("PlayList/convert_twenty", TRUE).toBool());
-    ui.fullPathCheckBox->setChecked(settings.value ("PlayList/full_stream_path", FALSE).toBool());
-
+    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
+    if (MediaPlayer *player = MediaPlayer::instance())
+    {
+        ui.formatLineEdit->setText(player->playListModel()->format());
+        ui.metadataCheckBox->setChecked(player->playListModel()->useMetadata());
+        ui.underscoresCheckBox->setChecked(player->playListModel()->convertUnderscore());
+        ui.per20CheckBox->setChecked(player->playListModel()->convertTwenty());
+    }
+    ui.protocolCheckBox->setChecked(settings.value ("PlayList/show_protocol", FALSE).toBool());
+    ui.numbersCheckBox->setChecked(settings.value ("PlayList/show_numbers", TRUE).toBool());
     //proxy settings
-    ui.enableProxyCheckBox->setChecked(
-        settings.value ("Proxy/use_proxy", FALSE).toBool());
-    ui.authProxyCheckBox->setChecked(
-        settings.value ("Proxy/authentication", FALSE).toBool());
-
-    ui.hostLineEdit->setText(settings.value("Proxy/host").toString());
-    ui.portLineEdit->setText(settings.value("Proxy/port").toString());
-    ui.proxyUserLineEdit->setText(settings.value("Proxy/user").toString());
-    ui.proxyPasswLineEdit->setText(settings.value("Proxy/passw").toString());
+    ui.enableProxyCheckBox->setChecked(Qmmp::useProxy());
+    ui.authProxyCheckBox->setChecked(Qmmp::useProxyAuth());
+    ui.hostLineEdit->setText(Qmmp::proxy().host());
+    if (Qmmp::proxy().port(0))
+        ui.portLineEdit->setText(QString::number(Qmmp::proxy().port(0)));
+    ui.proxyUserLineEdit->setText(Qmmp::proxy().userName());
+    ui.proxyPasswLineEdit->setText(Qmmp::proxy().password());
 
     ui.hostLineEdit->setEnabled(ui.enableProxyCheckBox->isChecked());
     ui.portLineEdit->setEnabled(ui.enableProxyCheckBox->isChecked());
@@ -120,7 +124,15 @@ void ConfigDialog::readSettings()
 
     ui.hiddenCheckBox->setChecked(settings.value("MainWindow/start_hidden", FALSE).toBool());
     ui.hideOnCloseCheckBox->setChecked(settings.value("MainWindow/hide_on_close", FALSE).toBool());
-    ui.softVolumeCheckBox->setChecked(settings.value("Volume/software_volume", FALSE).toBool());
+    //volume
+    ui.softVolumeCheckBox->setChecked(SoundCore::instance()->softwareVolume());
+    connect(ui.softVolumeCheckBox, SIGNAL(clicked(bool)), SoundCore::instance(), SLOT(setSoftwareVolume(bool)));
+    //transparency
+    ui.mwTransparencySlider->setValue(100 - settings.value("MainWindow/opacity", 1.0).toDouble()*100);
+    ui.eqTransparencySlider->setValue(100 - settings.value("Equalizer/opacity", 1.0).toDouble()*100);
+    ui.plTransparencySlider->setValue(100 - settings.value("PlayList/opacity", 1.0).toDouble()*100);
+    //compatibility
+    ui.openboxCheckBox->setChecked(settings.value("General/openbox_compat", FALSE).toBool());
 }
 
 void ConfigDialog::changePage (QListWidgetItem *current, QListWidgetItem *previous)
@@ -149,7 +161,9 @@ void ConfigDialog::changeSkin()
 
 void ConfigDialog::loadSkins()
 {
+    m_reader->generateThumbs();
     m_skinList.clear();
+    ui.listWidget->clear();
     QFileInfo fileInfo (":/default");
     QPixmap preview = Skin::getPixmap ("main", QDir (fileInfo.filePath()));
     QListWidgetItem *item = new QListWidgetItem (fileInfo.fileName ());
@@ -158,7 +172,11 @@ void ConfigDialog::loadSkins()
     m_skinList << fileInfo;
 
     findSkins(QDir::homePath() +"/.qmmp/skins");
+#ifdef Q_OS_WIN32
+    findSkins(qApp->applicationDirPath()+"/skins");
+#else
     findSkins(qApp->applicationDirPath()+"/../share/qmmp/skins");
+#endif
     foreach(QString path, m_reader->skins())
     {
         QListWidgetItem *item = new QListWidgetItem (path.section('/', -1));
@@ -167,8 +185,6 @@ void ConfigDialog::loadSkins()
         ui.listWidget->addItem (item);
         m_skinList << QFileInfo(path);
     }
-    connect (ui.listWidget, SIGNAL (itemClicked (QListWidgetItem *)),
-             this, SLOT (changeSkin()));
 }
 
 void ConfigDialog::findSkins(const QString &path)
@@ -198,8 +214,8 @@ void ConfigDialog::loadPluginsInfo()
         load input plugins information
     */
     QList <DecoderFactory *> *decoders = 0;
-    decoders = Decoder::decoderFactories();
-    QStringList files = Decoder::decoderFiles();
+    decoders = Decoder::factories();
+    QStringList files = Decoder::files();
     ui.inputPluginTable->setColumnCount ( 3 );
     ui.inputPluginTable->verticalHeader()->hide();
     ui.inputPluginTable->setHorizontalHeaderLabels ( QStringList()
@@ -210,6 +226,7 @@ void ConfigDialog::loadPluginsInfo()
         InputPluginItem *item = new InputPluginItem(this, decoders->at(i));
         m_inputPluginItems.append(item);
         QCheckBox* checkBox = new QCheckBox ( ui.inputPluginTable );
+        checkBox->setFocusPolicy (Qt::NoFocus);
         ui.inputPluginTable->setCellWidget ( i, 0, checkBox );
         checkBox->setChecked(item->isSelected());
         connect(checkBox, SIGNAL(toggled(bool)), item, SLOT(setSelected(bool)));
@@ -240,6 +257,7 @@ void ConfigDialog::loadPluginsInfo()
         OutputPluginItem *item = new OutputPluginItem(this,outputs->at(i));
         m_outputPluginItems.append(item);
         QRadioButton* button = new QRadioButton ( ui.outputPluginTable );
+        button->setFocusPolicy (Qt::NoFocus);
         ui.outputPluginTable->setCellWidget ( i, 0, button );
         button->setChecked ( item->isSelected() );
         connect(button, SIGNAL(pressed ()), item, SLOT(select()));
@@ -258,8 +276,8 @@ void ConfigDialog::loadPluginsInfo()
         load visual plugin information
     */
     QList <VisualFactory *> *visuals = 0;
-    visuals = Visual::visualFactories();
-    files = Visual::visualFiles();
+    visuals = Visual::factories();
+    files = Visual::files();
     ui.visualPluginTable->setColumnCount ( 3 );
     ui.visualPluginTable->verticalHeader()->hide();
     ui.visualPluginTable->setHorizontalHeaderLabels ( QStringList()
@@ -271,6 +289,7 @@ void ConfigDialog::loadPluginsInfo()
         VisualPluginItem *item = new VisualPluginItem(this,visuals->at(i));
         m_visualPluginItems.append(item);
         QCheckBox* button = new QCheckBox (ui.visualPluginTable);
+        button->setFocusPolicy (Qt::NoFocus);
         ui.visualPluginTable->setCellWidget ( i, 0, button );
         button->setChecked (item->isSelected());
         connect(button, SIGNAL(clicked (bool)), item, SLOT(select(bool)));
@@ -303,6 +322,7 @@ void ConfigDialog::loadPluginsInfo()
         EffectPluginItem *item = new EffectPluginItem(this,effects->at(i));
         m_effectPluginItems.append(item);
         QCheckBox* button = new QCheckBox (ui.effectPluginTable);
+        button->setFocusPolicy (Qt::NoFocus);
         ui.effectPluginTable->setCellWidget ( i, 0, button );
         button->setChecked (item->isSelected());
         connect(button, SIGNAL(clicked (bool)), item, SLOT(select(bool)));
@@ -335,6 +355,7 @@ void ConfigDialog::loadPluginsInfo()
         GeneralPluginItem *item = new GeneralPluginItem(this,generals->at(i));
         m_generalPluginItems.append(item);
         QCheckBox* button = new QCheckBox (ui.generalPluginTable);
+        button->setFocusPolicy (Qt::NoFocus);
         ui.generalPluginTable->setCellWidget ( i, 0, button );
         button->setChecked (item->isSelected());
         connect(button, SIGNAL(clicked (bool)), item, SLOT(select(bool)));
@@ -365,14 +386,17 @@ void ConfigDialog::loadPluginsInfo()
 
 void ConfigDialog::loadFonts()
 {
-    QSettings settings (QDir::homePath() +"/.qmmp/qmmprc", QSettings::IniFormat);
-    QString fontname = settings.value ( "PlayList/Font","" ).toString();
+    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
+    QString fontname = settings.value ( "PlayList/Font").toString();
     QFont font;
-    font.fromString(fontname);
+    if(!fontname.isEmpty())
+        font.fromString(fontname);
     ui.plFontLabel->setText (font.family () + " " + QString::number(font.pointSize ()));
     ui.plFontLabel->setFont(font);
 
-    fontname = settings.value ("MainWindow/Font","").toString();
+    fontname = settings.value ("MainWindow/Font").toString();
+    if(!fontname.isEmpty())
+        font.fromString(fontname);
     font.fromString(fontname);
     ui.mainFontLabel->setText (font.family () + " " + QString::number(font.pointSize ()));
     ui.mainFontLabel->setFont(font);
@@ -387,7 +411,7 @@ void ConfigDialog::setPlFont()
     {
         ui.plFontLabel->setText (font.family () + " " + QString::number(font.pointSize ()));
         ui.plFontLabel->setFont(font);
-        QSettings settings ( QDir::homePath() +"/.qmmp/qmmprc", QSettings::IniFormat );
+        QSettings settings ( Qmmp::configFile(), QSettings::IniFormat );
         settings.setValue ( "PlayList/Font", font.toString() );
     }
 }
@@ -401,7 +425,7 @@ void ConfigDialog::setMainFont()
     {
         ui.mainFontLabel->setText (font.family () + " " + QString::number(font.pointSize ()));
         ui.mainFontLabel->setFont(font);
-        QSettings settings ( QDir::homePath() +"/.qmmp/qmmprc", QSettings::IniFormat );
+        QSettings settings ( Qmmp::configFile(), QSettings::IniFormat );
         settings.setValue ( "MainWindow/Font", font.toString() );
     }
 }
@@ -413,7 +437,7 @@ void ConfigDialog::showPluginSettings()
     case 0:
     {
         QList <DecoderFactory *> *decoders = 0;
-        decoders = Decoder::decoderFactories();
+        decoders = Decoder::factories();
         int row = ui.inputPluginTable->currentRow ();
         if ( !decoders || row<0 )
             return;
@@ -434,7 +458,7 @@ void ConfigDialog::showPluginSettings()
         int row = ui.visualPluginTable->currentRow ();
         if ( m_visualPluginItems.isEmpty() || row < 0 )
             return;
-        m_visualPluginItems.at(row)->factory()->showSettings ( this );
+        Visual::showSettings(m_visualPluginItems.at(row)->factory(), this);
         break;
     }
     case 3:
@@ -514,7 +538,6 @@ void ConfigDialog::createMenus()
     menu->addAction(tr("Genre"))->setData("%g");
     menu->addAction(tr("Filename"))->setData("%f");
     menu->addAction(tr("Filepath"))->setData("%F");
-    menu->addAction(tr("Date"))->setData("%d");
     menu->addAction(tr("Year"))->setData("%y");
     menu->addAction(tr("Comment"))->setData("%c");
     ui.titleButton->setMenu(menu);
@@ -532,22 +555,32 @@ void ConfigDialog::addTitleString( QAction * a)
 
 void ConfigDialog::saveSettings()
 {
-    QSettings settings (QDir::homePath() +"/.qmmp/qmmprc", QSettings::IniFormat);
-    settings.setValue ("PlayList/title_format", ui.formatLineEdit->text());
-    settings.setValue ("PlayList/load_metadata", ui.metadataCheckBox->isChecked());
-    settings.setValue ("PlayList/convert_underscore", ui.underscoresCheckBox->isChecked());
-    settings.setValue ("PlayList/convert_twenty", ui.per20CheckBox->isChecked());
-    settings.setValue ("PlayList/full_stream_path", ui.fullPathCheckBox->isChecked());
+    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
+    if (MediaPlayer *player = MediaPlayer::instance())
+    {
+        player->playListModel()->setFormat(ui.formatLineEdit->text().trimmed());
+        player->playListModel()->setUseMetadata(ui.metadataCheckBox->isChecked());
+        player->playListModel()->setConvertUnderscore(ui.underscoresCheckBox->isChecked());
+        player->playListModel()->setConvertTwenty(ui.per20CheckBox->isChecked());
+    }
+    settings.setValue ("PlayList/show_protocol", ui.protocolCheckBox->isChecked());
+    settings.setValue ("PlayList/show_numbers", ui.numbersCheckBox->isChecked());
     FileDialog::setEnabled(FileDialog::registeredFactories().at(ui.fileDialogComboBox->currentIndex()));
-    settings.setValue ("Proxy/use_proxy", ui.enableProxyCheckBox->isChecked());
-    settings.setValue ("Proxy/authentication", ui.authProxyCheckBox->isChecked());
-    settings.setValue ("Proxy/host",ui.hostLineEdit->text());
-    settings.setValue ("Proxy/port",ui.portLineEdit->text());
-    settings.setValue ("Proxy/user",ui.proxyUserLineEdit->text());
-    settings.setValue ("Proxy/passw",ui.proxyPasswLineEdit->text());
-    settings.setValue ("Volume/software_volume", ui.softVolumeCheckBox->isChecked());
+
+    Qmmp::setProxyEnabled(ui.enableProxyCheckBox->isChecked());
+    Qmmp::setProxyAuthEnabled(ui.authProxyCheckBox->isChecked());
+    QUrl proxyUrl;
+    proxyUrl.setHost(ui.hostLineEdit->text());
+    proxyUrl.setPort(ui.portLineEdit->text().toUInt());
+    proxyUrl.setUserName(ui.proxyUserLineEdit->text());
+    proxyUrl.setPassword(ui.proxyPasswLineEdit->text());
+    Qmmp::setProxy(proxyUrl);
     settings.setValue ("MainWindow/start_hidden", ui.hiddenCheckBox->isChecked());
     settings.setValue ("MainWindow/hide_on_close", ui.hideOnCloseCheckBox->isChecked());
+    settings.setValue ("MainWindow/opacity", 1.0 -  (double)ui.mwTransparencySlider->value()/100);
+    settings.setValue ("Equalizer/opacity", 1.0 -  (double)ui.eqTransparencySlider->value()/100);
+    settings.setValue ("PlayList/opacity", 1.0 -  (double)ui.plTransparencySlider->value()/100);
+    settings.setValue("General/openbox_compat", ui.openboxCheckBox->isChecked());
 }
 
 void ConfigDialog::updateButtons()
@@ -622,3 +655,15 @@ void ConfigDialog::showFileDialogInfo()
     int index = ui.fileDialogComboBox->currentIndex ();
     FileDialog::registeredFactories()[index]->showAbout(this);
 }
+
+void ConfigDialog::installSkin()
+{
+    QStringList files = FileDialog::getOpenFileNames(this,tr("Select Skin Files"), QDir::homePath(),
+                        tr("Skin files") + " (*.tar.gz *.tgz *.tar.bz2 *.zip *.wsz)");
+    foreach(QString path, files)
+    {
+        QFile file(path);
+        file.copy(QDir::homePath() +"/.qmmp/skins/" + QFileInfo(path).fileName());
+    }
+    loadSkins();
+}
