@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,19 +26,20 @@
 #include <math.h>
 
 #include <qmmp/soundcore.h>
+#include <qmmp/visual.h>
 #include <qmmpui/generalhandler.h>
 #include <qmmpui/general.h>
 #include <qmmpui/playlistparser.h>
 #include <qmmpui/playlistformat.h>
 #include <qmmpui/commandlinemanager.h>
 #include <qmmpui/filedialog.h>
+#include <qmmpui/playlistmodel.h>
+#include <qmmpui/mediaplayer.h>
 
 #include "textscroller.h"
 #include "mainwindow.h"
-#include "fileloader.h"
 #include "skin.h"
 #include "playlist.h"
-#include "playlistmodel.h"
 #include "configdialog.h"
 #include "dock.h"
 #include "eqwidget.h"
@@ -50,7 +51,7 @@
 #include "visualmenu.h"
 #include "builtincommandlineoption.h"
 
-#define KEY_OFFSET 10
+#define KEY_OFFSET 10000
 
 MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option_manager, QWidget *parent)
         : QMainWindow(parent)
@@ -59,103 +60,97 @@ MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option
     seeking = FALSE;
     m_update = FALSE;
     m_paused = FALSE;
-    m_elapsed = 0;
+    m_playlistName = tr("Default");
     m_option_manager = option_manager;
-
     setWindowIcon(QIcon(":/32x32/qmmp.png"));
+#if QT_VERSION >= 0x040500
+    setWindowFlags(Qt::Window | Qt::FramelessWindowHint | Qt::WindowCloseButtonHint | Qt::WindowSystemMenuHint);
+#else
+    setWindowFlags(Qt::Window | Qt::FramelessWindowHint | Qt::WindowSystemMenuHint);
+#endif
+    //setFixedSize (275,116);
+    resize(275,116);
+    setWindowTitle("Qmmp");
 
+    //prepare libqmmp and libqmmpui libraries for playing
+    m_player = new MediaPlayer(this);
+    m_core = new SoundCore(this);
+    m_playListModel = new PlayListModel(this);
+    m_player->initialize(m_core, m_playListModel);
+    //additional featuries
+    new PlaylistParser(this);
+    m_generalHandler = new GeneralHandler(this);
+
+    //user interface
     m_skin = new Skin(this);
     Dock *dock = new Dock(this);
     dock->setMainWidget(this);
-
-    setWindowFlags(Qt::FramelessWindowHint);
-    setFixedSize (275,116);
-
     display = new MainDisplay(this);
     setCentralWidget(display);
     display->show();
     display->setFocus ();
 
-    m_playlistName = tr("Default");
-
-    new PlaylistParser(this);
     m_playlist = new PlayList(this);
-
-    connect (m_playlist,SIGNAL(next()),SLOT(next()));
-    connect (m_playlist,SIGNAL(prev()),SLOT(previous()));
-    connect (m_playlist,SIGNAL(play()),SLOT(play()));
-    connect (m_playlist,SIGNAL(pause()),SLOT(pause()));
-    connect (m_playlist,SIGNAL(stop()),SLOT(stop()));
-    connect (m_playlist,SIGNAL(eject()),SLOT(addFile()));
-
-    connect (m_playlist,SIGNAL(newPlaylist()),SLOT(newPlaylist()));
-    connect (m_playlist,SIGNAL(loadPlaylist()),SLOT(loadPlaylist()));
-    connect (m_playlist,SIGNAL(savePlaylist()),SLOT(savePlaylist()));
-
-    m_playListModel = new PlayListModel(this);
-
-    connect(display,SIGNAL(shuffleToggled(bool)),m_playListModel,SLOT(prepareForShufflePlaying(bool)));
-    connect(display,SIGNAL(repeatableToggled(bool)),m_playListModel,SLOT(prepareForRepeatablePlaying(bool)));
-
+    m_playlist->setModel(m_playListModel);
     dock->addWidget(m_playlist);
 
     m_equalizer = new EqWidget(this);
     dock->addWidget(m_equalizer);
-    connect(m_equalizer, SIGNAL(valueChanged()), SLOT(updateEQ()));
-
-    m_playlist->setModel(m_playListModel);
 
     m_jumpDialog = new JumpToTrackDialog(this);
     m_jumpDialog->setModel(m_playListModel);
-    connect(m_jumpDialog,SIGNAL(playRequest()),this,SLOT(play()));
     m_jumpDialog->hide();
 
-    createActions();
-
-    m_core = new SoundCore(this);
     m_titlebar = new TitleBar(this);
     m_titlebar->move(0,0);
     m_titlebar->show();
     m_titlebar->setActive(TRUE);
 
-    readSettings();
-    dock->updateDock();
-
-    display->setEQ(m_equalizer);
-    display->setPL(m_playlist);
-
+    createActions();
+    //prepare visualization
+    Visual::initialize(this, m_visMenu, SLOT(updateActions()));
     m_vis = MainVisual::getPointer();
+    Visual::add(m_vis);
+    //connections
+    connect (m_playlist,SIGNAL(next()),SLOT(next()));
+    connect (m_playlist,SIGNAL(prev()),SLOT(previous()));
+    connect (m_playlist,SIGNAL(play()),SLOT(play()));
+    connect (m_playlist,SIGNAL(pause()), m_core ,SLOT(pause()));
+    connect (m_playlist,SIGNAL(stop()),SLOT(stop()));
+    connect (m_playlist,SIGNAL(eject()),SLOT(addFile()));
+    connect (m_playlist,SIGNAL(newPlaylist()),SLOT(newPlaylist()));
+    connect (m_playlist,SIGNAL(loadPlaylist()),SLOT(loadPlaylist()));
+    connect (m_playlist,SIGNAL(savePlaylist()),SLOT(savePlaylist()));
 
-    m_core->addVisualization(m_vis);
-    m_core->showVisualization(this);
+    connect(display,SIGNAL(shuffleToggled(bool)),m_playListModel,SLOT(prepareForShufflePlaying(bool)));
+    connect(display,SIGNAL(repeatableToggled(bool)),m_playListModel,SLOT(prepareForRepeatablePlaying(bool)));
 
-    connect(m_core, SIGNAL(outputStateChanged(const OutputState&)),
-            SLOT(showOutputState(const OutputState&)));
-    connect(m_core, SIGNAL(decoderStateChanged(const DecoderState&)),
-            SLOT(showDecoderState(const DecoderState&)));
-    connect(m_core, SIGNAL(titleChanged(const QString&)),
-            SLOT(changeTitle(const QString&)));
+    connect(m_equalizer, SIGNAL(valueChanged()), SLOT(updateEQ()));
+
+    connect(m_jumpDialog,SIGNAL(playRequest()),this,SLOT(play()));
+
+    //connect(m_core, SIGNAL(finished()), SLOT(next()));
+    connect(m_core, SIGNAL(stateChanged(Qmmp::State)), SLOT(showState(Qmmp::State)));
+    connect(m_core, SIGNAL(elapsedChanged(qint64)),m_playlist, SLOT(setTime(qint64)));
+    connect(m_core, SIGNAL(elapsedChanged(qint64)),m_titlebar, SLOT(setTime(qint64)));
+    connect(m_core, SIGNAL(metaDataChanged()),SLOT(showMetaData()));
     connect(m_core, SIGNAL(bufferingProgress(int)), TextScroller::getPointer(),
             SLOT(setProgress(int)));
 
-    updateEQ();
-
-    m_generalHandler = new GeneralHandler(this);
-    connect(m_generalHandler, SIGNAL(playCalled()), SLOT(play()));
-    connect(m_generalHandler, SIGNAL(nextCalled()), SLOT(next()));
-    connect(m_generalHandler, SIGNAL(previousCalled()), SLOT(previous()));
-    connect(m_generalHandler, SIGNAL(stopCalled()), SLOT(stop()));
-    connect(m_generalHandler, SIGNAL(pauseCalled()), SLOT(pause()));
-    connect(m_generalHandler, SIGNAL(seekCalled(int)), SLOT(seek(int)));
     connect(m_generalHandler, SIGNAL(toggleVisibilityCalled()), SLOT(toggleVisibility()));
     connect(m_generalHandler, SIGNAL(exitCalled()), SLOT(close()));
-    connect(m_generalHandler, SIGNAL(volumeChanged(int, int)),
-            m_core, SLOT(setVolume(int, int)));
 
-    m_playListModel->readSettings();
-    char buf[PATH_MAX + 1];
-    QString cwd = QString::fromLocal8Bit(getcwd(buf,PATH_MAX));
+    readSettings();
+    display->setEQ(m_equalizer);
+    display->setPL(m_playlist);
+    dock->updateDock();
+    //m_playListModel->readSettings();
+    m_playListModel->doCurrentVisibleRequest();
+    updateEQ();
+#ifndef Q_OS_WIN32
+    QString cwd = QDir::currentPath();
     processCommandArgs(args,cwd);
+#endif
     if (m_startHidden && m_generalHandler->visibilityControl())
         toggleVisibility();
 }
@@ -163,65 +158,12 @@ MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option
 
 MainWindow::~MainWindow()
 {
-    stop();
+    //stop();
 }
 
 void MainWindow::play()
 {
-    disconnect(m_playListModel, SIGNAL(firstAdded()), this, SLOT(play()));
-    m_playListModel->doCurrentVisibleRequest();
-
-    if (m_core->isPaused())
-    {
-        pause();
-        return;
-    }
-    stop();
-    if (m_playListModel->count() == 0)
-        return;
-
-    m_equalizer->loadPreset(m_playListModel->currentItem()->fileName());
-    m_playListModel->currentItem()->updateTags();
-    m_playlist->listWidget()->updateList();
-    QString s = m_playListModel->currentItem()->path();
-    if (s.isEmpty())
-        return;
-    if (m_core->play(s))
-    {
-        display->setTime(0);
-        m_generalHandler->setTime(0);
-        display->setMaxTime(m_core->length());
-    }
-    else
-    {
-        //find out the reason why the playback failed
-        switch ((int) m_core->error())
-        {
-        case SoundCore::OutputError:
-        {
-            stop();
-            return; //unrecovable error in output, so abort playing
-        }
-        case SoundCore::DecoderError:
-        {
-            //error in decoder, so we should try to play next song
-            qApp->processEvents();
-            if (!m_playListModel->isEmptyQueue())
-            {
-                m_playListModel->setCurrentToQueued();
-            }
-            else if (!m_playListModel->next())
-            {
-                stop();
-                display->hideTimeDisplay();
-                return;
-            }
-            m_playlist->update();
-            play();
-            break;
-        }
-        }
-    }
+    m_player->play();
 }
 
 void MainWindow::replay()
@@ -230,7 +172,7 @@ void MainWindow::replay()
     play();
 }
 
-void MainWindow::seek(int pos)
+void MainWindow::seek(qint64 pos)
 {
     if (!seeking)
         m_core->seek(pos);
@@ -239,12 +181,12 @@ void MainWindow::seek(int pos)
 
 void MainWindow::forward()
 {
-    seek(m_elapsed + KEY_OFFSET);
+    seek(m_core->elapsed() + KEY_OFFSET);
 }
 
 void MainWindow::backward()
 {
-    seek(qMax(0,m_elapsed - KEY_OFFSET));
+    seek(qMax(qint64(0), m_core->elapsed() - KEY_OFFSET));
 }
 
 void MainWindow::setVolume(int volume, int balance)
@@ -260,167 +202,82 @@ void MainWindow::pause(void)
 
 void MainWindow::stop()
 {
-    display->setTime(0);
+    //display->setTime(0);
     m_core->stop();
 }
+
 void MainWindow::next()
 {
-    if (!m_playListModel->isEmptyQueue())
-    {
-        m_playListModel->setCurrentToQueued();
-    }
-    else if (!m_playListModel->next())
-    {
-        stop();
-        display->hideTimeDisplay();
-        return;
-    }
-    m_playlist->update();
-    if (m_core->isInitialized())
-    {
-        stop();
-        m_elapsed = 0;
-        play();
-    }
-    else
-        display->hideTimeDisplay();
+    m_player->next();
 }
+
 void MainWindow::previous()
 {
-    if (!m_playListModel->previous())
-    {
-        display->hideTimeDisplay();
-        return;
-    }
-
-    m_playlist->update();
-    if (m_core->isInitialized())
-    {
-        stop();
-        play();
-    }
-    else
-        display->hideTimeDisplay();
+    m_player->previous();
 }
 
 void MainWindow::updateEQ()
 {
-    int b[10];
+    double b[10];
     for (int i=0; i<10; ++i)
         b[i] = m_equalizer->gain(i);
     m_core->setEQ(b, m_equalizer->preamp());
     m_core->setEQEnabled(m_equalizer->isEQEnabled());
 }
 
-void MainWindow::showOutputState(const OutputState &st)
-
+void MainWindow::showState(Qmmp::State state)
 {
-    if (seeking)
-        return;
-
-    display->setInfo(st);
-    m_playlist->setInfo(st, m_core->length(), m_playListModel->totalLength());
-    m_titlebar->setInfo(st);
-    m_equalizer->setInfo(st);
-    switch ((int) st.type())
+    disconnect(m_playListModel, SIGNAL(firstAdded()), this, SLOT(play()));
+    switch ((int) state)
     {
-    case OutputState::Playing:
+    case Qmmp::Playing:
     {
-        m_generalHandler->setState(General::Playing);
         if (m_playListModel->currentItem())
-        {
-            SongInfo info = *m_playListModel->currentItem();
-            if (info.isEmpty())
-                info.setValue(SongInfo::TITLE, m_playlist->currentItem()->text());
-            m_generalHandler->setSongInfo(info);
-        }
+            m_equalizer->loadPreset(m_playListModel->currentItem()->url().section("/",-1));
+        if (m_playlist->listWidget())
+            m_playlist->listWidget()->updateList(); //removes progress message from TextScroller
         break;
     }
-    case OutputState::Paused:
+    case Qmmp::Paused:
     {
-        m_generalHandler->setState(General::Paused);
+        //m_generalHandler->setState(General::Paused);
         break;
     }
-    case OutputState::Stopped:
+    case Qmmp::Stopped:
     {
-        m_generalHandler->setState(General::Stopped);
-        break;
-    }
-    case OutputState::Info:
-    {
-        m_generalHandler->setTime(st.elapsedSeconds());
-        m_elapsed = st.elapsedSeconds();
-        break;
-    }
-    case OutputState::Volume:
-    {
-        m_generalHandler->setVolume(st.leftVolume(), st.rightVolume());
-        break;
-    }
-    case OutputState::VisualRemoved:
-    {
-        m_visMenu->updateActions();
-    }
-    }
-}
-void MainWindow::showDecoderState(const DecoderState &st)
-{
-    switch ((int) st.type())
-    {
-    case DecoderState::Finished:
-    {
-        next();
-        break;
-    }
-    case DecoderState::Info:
-    {
-        qDebug("file info:");
-        qDebug("ARTIST = %s", qPrintable(st.tag()->artist()));
-        qDebug("TITLE = %s", qPrintable(st.tag()->title()));
-        qDebug("ALBUM = %s", qPrintable(st.tag()->album()));
-        qDebug("COMMENT = %s", qPrintable(st.tag()->comment()));
-        qDebug("GENRE = %s", qPrintable(st.tag()->genre()));
-        qDebug("YEAR = %d", st.tag()->year());
-        qDebug("TRACK = %d", st.tag()->track());
-        qDebug("LENGTH = %d", st.tag()->length());
+        //m_generalHandler->setState(General::Stopped);
+        m_playlist->setTime(-1);
+        m_titlebar->setTime(-1);
         if (m_playlist->currentItem())
-        {
-            if (!st.tag()->isEmpty())
-            {
-                SongInfo info;
-                info.setValue(SongInfo::TITLE, st.tag()->title());
-                info.setValue(SongInfo::ARTIST, st.tag()->artist());
-                info.setValue(SongInfo::ALBUM, st.tag()->album());
-                info.setValue(SongInfo::COMMENT, st.tag()->comment());
-                info.setValue(SongInfo::GENRE, st.tag()->genre());
-                info.setValue(SongInfo::YEAR, st.tag()->year());
-                info.setValue(SongInfo::TRACK, st.tag()->track());
-                info.setValue(SongInfo::LENGTH, st.tag()->length());
-                info.setValue(SongInfo::STREAM,
-                              m_playlist->currentItem()->path().startsWith("http://"));
-                info.setValue(SongInfo::PATH, m_playlist->currentItem()->path());
-                m_generalHandler->setSongInfo(info);
-            }
-            m_playlist->currentItem()->updateTags(st.tag());
-            m_playlist->updateList();
-        }
+            setWindowTitle(m_playlist->currentItem()->text());
+        else
+            setWindowTitle("Qmmp");
         break;
     }
     }
 }
-
-void MainWindow::changeTitle(const QString &title)
+void MainWindow::showMetaData()
 {
-    if (m_playlist->currentItem())
-        m_playlist->currentItem()->setText(title);
-    m_playlist->updateList();
-    SongInfo info;
-    info.setValue(SongInfo::TITLE, title);
-    info.setValue(SongInfo::STREAM, TRUE);
-    m_generalHandler->setSongInfo(info);
+    qDebug("===== metadata ======");
+    qDebug("ARTIST = %s", qPrintable(m_core->metaData(Qmmp::ARTIST)));
+    qDebug("TITLE = %s", qPrintable(m_core->metaData(Qmmp::TITLE)));
+    qDebug("ALBUM = %s", qPrintable(m_core->metaData(Qmmp::ALBUM)));
+    qDebug("COMMENT = %s", qPrintable(m_core->metaData(Qmmp::COMMENT)));
+    qDebug("GENRE = %s", qPrintable(m_core->metaData(Qmmp::GENRE)));
+    qDebug("YEAR = %s", qPrintable(m_core->metaData(Qmmp::YEAR)));
+    qDebug("TRACK = %s", qPrintable(m_core->metaData(Qmmp::TRACK)));
+    qDebug("== end of metadata ==");
+
+    if (m_playlist->currentItem() && !m_core->metaData().isEmpty())
+    {
+        m_playlist->currentItem()->updateMetaData(m_core->metaData());
+        m_playlist->updateList();
+        TextScroller::getPointer()->setText(m_playlist->currentItem()->text());
+        setWindowTitle(m_playlist->currentItem()->text());
+    }
 }
 
-void MainWindow::closeEvent ( QCloseEvent *)
+void MainWindow::closeEvent (QCloseEvent *)
 {
     writeSettings();
     m_playlist->close();
@@ -470,7 +327,7 @@ void MainWindow::changeEvent (QEvent * event)
 
 void MainWindow::readSettings()
 {
-    QSettings settings(QDir::homePath()+"/.qmmp/qmmprc", QSettings::IniFormat);
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     if (!m_update)
     {
         settings.beginGroup("MainWindow");
@@ -481,7 +338,7 @@ void MainWindow::readSettings()
         m_startHidden = settings.value("start_hidden", FALSE).toBool();
         settings.endGroup();
         show();
-
+        qApp->processEvents();
         //visibility
         m_playlist->setVisible(settings.value("Playlist/visible",TRUE).toBool());
         m_equalizer->setVisible(settings.value("Equalizer/visible",TRUE).toBool());
@@ -499,12 +356,15 @@ void MainWindow::readSettings()
 
         m_update = TRUE;
     }
+    setWindowOpacity(settings.value("MainWindow/opacity", 1.0).toDouble());
+    m_equalizer->setWindowOpacity(settings.value("Equalizer/opacity", 1.0).toDouble());
+    m_playlist->setWindowOpacity(settings.value("PlayList/opacity", 1.0).toDouble());
     m_hideOnClose = settings.value("MainWindow/hide_on_close", FALSE).toBool();
 }
 
 void MainWindow::writeSettings()
 {
-    QSettings settings(QDir::homePath()+"/.qmmp/qmmprc", QSettings::IniFormat);
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     settings.beginGroup("MainWindow");
     //geometry
     settings.setValue("pos", this->pos());
@@ -530,7 +390,7 @@ void MainWindow::showSettings()
         readSettings();
         m_playlist->readSettings();
         TextScroller::getPointer()->readSettings();
-        m_core->updateConfig();
+        //m_core->updateConfig();
         m_visMenu->updateActions();
     }
     delete m_confDialog;
@@ -541,8 +401,12 @@ void MainWindow::toggleVisibility()
     if (isHidden())
     {
         show();
+        raise();
+        activateWindow();
         m_playlist->setVisible(display->isPlaylistVisible());
         m_equalizer->setVisible(display->isEqualizerVisible());
+        qApp->processEvents();
+        setFocus ();
         if (isMinimized())
         {
             if (isMaximized())
@@ -550,34 +414,49 @@ void MainWindow::toggleVisibility()
             else
                 showNormal();
         }
-        raise();
-        activateWindow();
     }
     else
     {
-        hide();
         if (m_playlist->isVisible())
             m_playlist->hide();
         if (m_equalizer->isVisible())
             m_equalizer->hide();
+        hide();
     }
+    qApp->processEvents();
 }
 
 void MainWindow::createActions()
 {
     m_mainMenu = new QMenu(this);
     m_mainMenu->addAction(tr("&Play"),this, SLOT(play()), tr("X"));
-    m_mainMenu->addAction(tr("&Pause"),this, SLOT(pause()), tr("C"));
+    m_mainMenu->addAction(tr("&Pause"),m_core, SLOT(pause()), tr("C"));
     m_mainMenu->addAction(tr("&Stop"),this, SLOT(stop()), tr("V"));
     m_mainMenu->addAction(tr("&Previous"),this, SLOT(previous()), tr("Z"));
     m_mainMenu->addAction(tr("&Next"),this, SLOT(next()), tr("B"));
     m_mainMenu->addAction(tr("&Play/Pause"),this, SLOT(playPause()), tr("Space"));
     m_mainMenu->addSeparator();
+    QAction *repeateAllAction = m_mainMenu->addAction(tr("&Repeat Playlist"));
+    QAction *repeateTrackAction = m_mainMenu->addAction(tr("&Repeat Track"));
+    QAction *shuffleAction = m_mainMenu->addAction(tr("&Shuffle"));
+    repeateAllAction->setCheckable (TRUE);
+    repeateTrackAction->setCheckable (TRUE);
+    shuffleAction->setCheckable (TRUE);
+    repeateAllAction->setShortcut(tr("R")) ;
+    repeateTrackAction->setShortcut(tr("Ctrl+R")) ;
+    shuffleAction->setShortcut(tr("S")) ;
+    connect(repeateAllAction, SIGNAL(triggered (bool)), m_playListModel, SLOT(prepareForRepeatablePlaying(bool)));
+    connect(repeateTrackAction, SIGNAL(triggered (bool)), m_player, SLOT(setRepeatable(bool)));
+    connect(shuffleAction, SIGNAL(triggered (bool)), m_playListModel, SLOT(prepareForShufflePlaying(bool)));
+    connect(m_playListModel, SIGNAL(repeatableListChanged(bool)), repeateAllAction, SLOT(setChecked(bool)));
+    connect(m_player, SIGNAL (repeatableChanged(bool)), repeateTrackAction, SLOT(setChecked(bool)));
+    connect(m_playListModel, SIGNAL(shuffleChanged(bool)), shuffleAction, SLOT(setChecked(bool)));
+    m_mainMenu->addSeparator();
     m_mainMenu->addAction(tr("&Jump To File"),this, SLOT(jumpToFile()), tr("J"));
     m_mainMenu->addSeparator();
     m_visMenu = new VisualMenu(this);
     m_mainMenu->addMenu(m_visMenu);
-
+    m_mainMenu->addMenu(m_generalHandler->createMenu(GeneralHandler::TOOLS_MENU, tr("Tools"), this));
     m_mainMenu->addSeparator();
     m_mainMenu->addAction(tr("&Settings"), this, SLOT(showSettings()), tr("Ctrl+P"));
     m_mainMenu->addSeparator();
@@ -668,7 +547,10 @@ void MainWindow::savePlaylist()
 
 void MainWindow::setFileList(const QStringList & l)
 {
-    connect(m_playListModel, SIGNAL(firstAdded()), SLOT(play()));
+    if (m_core->state() == Qmmp::Playing || m_core->state() == Qmmp::Paused)
+        stop();
+    qApp->processEvents(); //receive stop signal
+    connect(m_playListModel, SIGNAL(firstAdded()), this, SLOT(play()));
     if (!m_playListModel->setFileList(l))
     {
         disconnect(m_playListModel, SIGNAL(firstAdded()), this, SLOT(play()));
@@ -678,8 +560,8 @@ void MainWindow::setFileList(const QStringList & l)
 
 void MainWindow::playPause()
 {
-    if (m_core->isInitialized())
-        pause();
+    if (m_core->state() == Qmmp::Playing)
+        m_core->pause();
     else
         play();
 }
@@ -689,12 +571,27 @@ bool MainWindow::processCommandArgs(const QStringList &slist,const QString& cwd)
     if (slist.count() > 0)
     {
         QString str = slist[0];
-        if (str.startsWith("--")) // is it a command?
+
+        if (str.startsWith("--enqueue") || str.startsWith("-e")) //check for "--enqueue" modifier
+        {
+            if (slist.count() < 2)
+                return FALSE;
+            QStringList full_path_list;
+            for (int i = 1; i < slist.count(); ++i)
+            {
+                if ((slist.at(i).startsWith("/")) || (slist.at(i).contains("://")))   //is it absolute path or url?
+                    full_path_list << slist.at(i);
+                else
+                    full_path_list << cwd + "/" + slist.at(i);
+            }
+            m_playListModel->addFileList(full_path_list); //TODO url support
+        }
+        else if (str.startsWith("-")) // is it a command?
         {
             if (CommandLineManager::hasOption(str))
                 m_generalHandler->executeCommand(str);
             else if (m_option_manager->identify(str))
-                m_option_manager->executeCommand(str,this);
+                m_option_manager->executeCommand(str, this);
             else
                 return FALSE;
         }
@@ -703,13 +600,12 @@ bool MainWindow::processCommandArgs(const QStringList &slist,const QString& cwd)
             QStringList full_path_list;
             foreach(QString s,slist)
             {
-                qWarning(qPrintable(cwd + "/" + s));
-                if (s.left(1) == "/")   //is it absolute path?
+                if ((s.startsWith("/")) || (s.contains("://")))   //is it absolute path or url?
                     full_path_list << s;
                 else
                     full_path_list << cwd + "/" + s;
             }
-            setFileList(full_path_list);
+            setFileList(full_path_list); //TODO url support
         }
     }
     return TRUE;
