@@ -29,6 +29,7 @@
 #include <QImage>
 #include <QBuffer>
 
+#include <qmmp/qmmp.h>
 #include "skin.h"
 
 Skin *Skin::pointer = 0;
@@ -60,7 +61,7 @@ Skin::Skin (QObject *parent)
         : QObject (parent)
 {
     pointer = this;
-    QSettings settings(QDir::homePath()+"/.qmmp/qmmprc", QSettings::IniFormat);
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     QString path = settings.value("skin_path","").toString();
     if (path.isEmpty() || !QDir(path).exists ())
         path = ":/default";
@@ -76,7 +77,7 @@ Skin::~Skin()
 
 void Skin::setSkin (const QString& path)
 {
-    QSettings settings(QDir::homePath()+"/.qmmp/qmmprc", QSettings::IniFormat);
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     settings.setValue("skin_path",path);
 
     qDebug ("Skin: set skin %s",qPrintable(path));    //TODO don't clear lists
@@ -209,18 +210,25 @@ void Skin::loadNumbers()
         pixmap = getDummyPixmap("numbers");
 
     for (uint i = 0; i < 10; i++)
-        m_numbers << pixmap->copy (i*9, 0, 9, 13);
+        m_numbers << pixmap->copy (i*9, 0, 9, pixmap->height());
 
     if (pixmap->width() > 107)
-        m_numbers << pixmap->copy(99, 0, 9,13);
+        m_numbers << pixmap->copy(99, 0, 9, pixmap->height());
     else
     {
         // We didn't find "-" symbol. So we have to extract it from "2".
         // Winamp uses this method too.
-        QPixmap pix = pixmap->copy(90,0,9,13);
-        QPixmap minus = pixmap->copy(18,6,9,1);
+        QPixmap pix;
+        if(pixmap->width() > 98)
+            pix = pixmap->copy(90,0,9,pixmap->height());
+        else
+        {
+            pix = QPixmap(9, pixmap->height());
+            pix.fill(Qt::transparent);
+        }
+        QPixmap minus = pixmap->copy(18,pixmap->height()/2,9,1);
         QPainter paint(&pix);
-        paint.drawPixmap(0,6, minus);
+        paint.drawPixmap(0,pixmap->height()/2, minus);
         m_numbers << pix;
     }
     delete pixmap;
